@@ -36,9 +36,14 @@ exception statement from your version. */
 
 package gnu.java.awt;
 
-import java.awt.geom.*;
-import java.awt.image.*;
 import java.awt.RenderingHints;
+import java.awt.geom.Point2D;
+import java.awt.geom.Rectangle2D;
+import java.awt.image.ComponentSampleModel;
+import java.awt.image.DataBuffer;
+import java.awt.image.Raster;
+import java.awt.image.RasterOp;
+import java.awt.image.WritableRaster;
 
 /**
  * This raster copy operation assumes that both source and destination
@@ -48,7 +53,7 @@ import java.awt.RenderingHints;
  * @throws java.lang.ClassCastException if the sample models of the
  * rasters are not of type ComponentSampleModel.
  * 
- * @author Rolf W. Rasmussen <rolfwr@ii.uib.no>
+ * @author Rolf W. Rasmussen (rolfwr@ii.uib.no)
  */
 public class ComponentDataBlitOp implements RasterOp
 {
