@@ -38,14 +38,24 @@ exception statement from your version. */
 
 package gnu.java.awt.peer;
 
-import java.awt.*;
-import java.awt.peer.*;
-import java.awt.font.*;
-import java.awt.geom.*;
-import java.text.*;
-import java.util.*;
-import gnu.java.awt.*;
+import gnu.java.awt.ClasspathToolkit;
 
+import java.awt.Font;
+import java.awt.FontMetrics;
+import java.awt.Toolkit;
+import java.awt.font.FontRenderContext;
+import java.awt.font.GlyphVector;
+import java.awt.font.LineMetrics;
+import java.awt.font.TextAttribute;
+import java.awt.font.TransformAttribute;
+import java.awt.geom.AffineTransform;
+import java.awt.geom.Rectangle2D;
+import java.awt.peer.FontPeer;
+import java.text.AttributedCharacterIterator;
+import java.text.CharacterIterator;
+import java.util.HashMap;
+import java.util.Locale;
+import java.util.Map;
 
 /**
  * A peer for fonts that are used inside Classpath. The purpose of
@@ -160,7 +170,7 @@ public abstract class ClasspathFontPeer
     return name;
   }
 
-  protected static void copyStyleToAttrs (int style, Map attrs)
+  public static void copyStyleToAttrs (int style, Map attrs)
   {
     if ((style & Font.BOLD) == Font.BOLD)
       attrs.put (TextAttribute.WEIGHT, TextAttribute.WEIGHT_BOLD);
@@ -179,7 +189,7 @@ public abstract class ClasspathFontPeer
       attrs.put (TextAttribute.FAMILY, fam);
   }
   
-  protected static void copySizeToAttrs (float size, Map attrs)
+  public static void copySizeToAttrs (float size, Map attrs)
   {
     attrs.put (TextAttribute.SIZE, new Float (size));
   }
@@ -218,7 +228,7 @@ public abstract class ClasspathFontPeer
     AffineTransform trans = this.transform;
     float size = this.size;
     int style = this.style;
-    
+
     if (attribs.containsKey (TextAttribute.FAMILY))
       family = (String) attribs.get (TextAttribute.FAMILY);
 
@@ -243,7 +253,13 @@ public abstract class ClasspathFontPeer
       {
         Float sz = (Float) attribs.get (TextAttribute.SIZE);
         size = sz.floatValue ();
+
+        // Pango doesn't accept 0 as a font size.
+        if (size < 1)
+          size = 1;
       }
+    else
+      size = 12;
 
     if (attribs.containsKey (TextAttribute.TRANSFORM))
       {
