@@ -114,19 +114,22 @@ public class GdkGraphics2D extends Graphics2D
   
   private final int native_state = GtkGenericPeer.getUniqueInteger();  
 
-  private Paint paint;
-  private Stroke stroke;
-  private Color fg;
-  private Color bg;
-  private Shape clip;
-  private AffineTransform transform;
+  // These are package-private to avoid accessor methods.
+  Paint paint;
+  Stroke stroke;
+  Color fg;
+  Color bg;
+  Shape clip;
+  AffineTransform transform;
   private GtkComponentPeer component;
-  private Font font;
+  // This is package-private to avoid an accessor method.
+  Font font;
   private RenderingHints hints;
   private BufferedImage bimage;
   private boolean pixelConversionRequired;
   private int[] pixelBuffer;
-  private Composite comp;
+  // This is package-private to avoid an accessor method.
+  Composite comp;
   private Stack stateStack;
 
   private native void initState(GtkComponentPeer component);
