@@ -230,7 +230,7 @@ public class GtkImage extends Image implements ImageConsumer
 	     int offset, int scansize)
   {
     setPixels (x, y, width, height, cm, convertPixels (pixels), offset,
-	       scansize);
+               scansize);
 
     if (observer != null)
       observer.imageUpdate (this,
@@ -255,7 +255,8 @@ public class GtkImage extends Image implements ImageConsumer
 
     if (scansize == width && height == 1)
       {
-	System.arraycopy (pixels, offset, 
+        // Copy contents of pixels array into pixel cache.
+	System.arraycopy (pixels, offset,
 			  pixelCache, y * this.width + x,
 			  pixels.length - offset);
       }
@@ -274,7 +275,7 @@ public class GtkImage extends Image implements ImageConsumer
     if (status == ImageConsumer.STATICIMAGEDONE && isCacheable)
       isLoaded = true;
 
-    if (status == ImageConsumer.SINGLEFRAMEDONE)
+    if (status == ImageConsumer.SINGLEFRAME)
       isCacheable = false;
 
     if (observer != null)
@@ -289,7 +290,7 @@ public class GtkImage extends Image implements ImageConsumer
 				-1, -1, -1, -1);
       }
 
-    if (source != null)
+    if (source != null && status != ImageConsumer.SINGLEFRAME)
       source.removeConsumer (this);
   }
 
