@@ -48,6 +48,9 @@ import java.lang.reflect.Method;
 import java.util.Arrays;
 import java.util.Enumeration;
 import java.util.Hashtable;
+import java.util.Iterator;
+import java.util.Map;
+import java.util.TreeMap;
 import java.util.Vector;
 
 /**
@@ -66,7 +69,10 @@ import java.util.Vector;
  **/
 
 public class BeanInfoEmbryo {
-	Hashtable properties = new Hashtable();
+
+	// by using a TreeMap the properties will be sorted alphabetically by name
+	// which matches the (undocumented) behavior of jdk
+	TreeMap properties = new TreeMap();
 	Hashtable events = new Hashtable();
 	Vector methods = new Vector();
 
@@ -85,9 +91,9 @@ public class BeanInfoEmbryo {
 
 		PropertyDescriptor[] Aproperties = new PropertyDescriptor[properties.size()];
 		int i = 0;
-		Enumeration e = properties.elements();
-		while (e.hasMoreElements()) {
-			Aproperties[i] = (PropertyDescriptor) e.nextElement();
+		Iterator it = properties.entrySet().iterator();
+		while (it.hasNext()) {
+			Aproperties[i] = (PropertyDescriptor) (((Map.Entry)it.next()).getValue());
 			if(defaultPropertyName != null && Aproperties[i].getName().equals(defaultPropertyName)) {
 				defaultProperty = i;
 			}
@@ -96,7 +102,7 @@ public class BeanInfoEmbryo {
 
 		EventSetDescriptor[] Aevents = new EventSetDescriptor[events.size()];
 		i = 0;
-		e = events.elements();
+		Enumeration e = events.elements();
 		while (e.hasMoreElements()) {
 			Aevents[i] = (EventSetDescriptor) e.nextElement();
 			if(defaultEventName != null && Aevents[i].getName().equals(defaultEventName)) {
