@@ -33,7 +33,7 @@ module.  An independent module is a module which is not derived from
 or based on this library.  If you modify this library, you may extend
 this exception to your version of the library, but you are not
 obligated to do so.  If you do not wish to do so, delete this
-exception statement from your version.  */
+exception statement from your version. */
 
 package gnu.java.net.protocol.file;
 
@@ -42,13 +42,16 @@ import gnu.classpath.SystemProperties;
 import java.io.BufferedInputStream;
 import java.io.BufferedOutputStream;
 import java.io.ByteArrayInputStream;
+import java.io.ByteArrayOutputStream;
 import java.io.File;
 import java.io.FileInputStream;
 import java.io.FileOutputStream;
 import java.io.FilePermission;
-import java.io.InputStream;
 import java.io.IOException;
+import java.io.InputStream;
 import java.io.OutputStream;
+import java.io.OutputStreamWriter;
+import java.io.Writer;
 import java.net.ProtocolException;
 import java.net.URL;
 import java.net.URLConnection;
@@ -61,9 +64,9 @@ import java.util.Locale;
  * This subclass of java.net.URLConnection models a URLConnection via
  * the "file" protocol.
  *
- * @author Aaron M. Renn <arenn@urbanophile.com>
- * @author Nic Ferrier <nferrier@tapsellferrier.co.uk>
- * @author Warren Levy <warrenl@cygnus.com>
+ * @author Aaron M. Renn (arenn@urbanophile.com)
+ * @author Nic Ferrier (nferrier@tapsellferrier.co.uk)
+ * @author Warren Levy (warrenl@cygnus.com)
  */
 public class Connection extends URLConnection
 {
@@ -91,6 +94,11 @@ public class Connection extends URLConnection
    */
   private File file;
 
+  /**
+   * If a directory, contains a list of files in the directory.
+   */
+  private byte[] directoryListing;
+
   /**
    * InputStream if we are reading from the file
    */
@@ -140,13 +148,7 @@ public class Connection extends URLConnection
       {
 	if (doInput)
 	  {
-	    StringBuffer sb = new StringBuffer();
-	    String[] files = file.list();
-
-	    for (int index = 0; index < files.length; ++index)
-	       sb.append(files[index]).append(StaticData.lineSeparator);
-
-	    inputStream = new ByteArrayInputStream(sb.toString().getBytes());
+            inputStream = new ByteArrayInputStream(getDirectoryListing());
 	  }
 
 	if (doOutput)
@@ -156,6 +158,32 @@ public class Connection extends URLConnection
     
     connected = true;
   }
+
+  /**
+   * Populates the <code>directoryListing</code> field with a byte array
+   * containing a representation of the directory listing.
+   */
+  byte[] getDirectoryListing()
+    throws IOException
+  {
+    if (directoryListing == null)
+      {
+        ByteArrayOutputStream sink = new ByteArrayOutputStream();
+        // NB uses default character encoding for this system
+        Writer writer = new OutputStreamWriter(sink);
+    
+        String[] files = file.list();
+    
+        for (int i = 0; i < files.length; i++)
+          {
+            writer.write(files[i]);
+            writer.write(StaticData.lineSeparator);
+          }
+
+        directoryListing = sink.toByteArray();
+      }
+    return directoryListing;  
+  }
   
   /**
    * Opens the file for reading and returns a stream for it.
@@ -229,7 +257,13 @@ public class Connection extends URLConnection
 	if (field.equals("content-type"))
           return guessContentTypeFromName(file.getName());
 	else if (field.equals("content-length"))
-          return Long.toString(file.length());
+          {
+            if (file.isDirectory())
+              {
+                return Integer.toString(getContentLength());
+              }
+            return Long.toString(file.length());
+          }
 	else if (field.equals("last-modified"))
 	  {
 	    synchronized (StaticData.dateFormat)
@@ -258,6 +292,10 @@ public class Connection extends URLConnection
 	if (!connected)
 	  connect();
         
+        if (file.isDirectory())
+          {
+            return getDirectoryListing().length;
+          }
 	return (int) file.length();
       }
     catch (IOException e)
