@@ -63,8 +63,8 @@ import javax.accessibility.AccessibleStateSet;
 /**
  * This class represents a top-level window with no decorations.
  *
- * @author Aaron M. Renn <arenn@urbanophile.com>
- * @author Warren Levy  <warrenl@cygnus.com>
+ * @author Aaron M. Renn (arenn@urbanophile.com)
+ * @author Warren Levy  (warrenl@cygnus.com)
  */
 public class Window extends Container implements Accessible
 {
@@ -90,8 +90,14 @@ public class Window extends Container implements Accessible
 
   private transient boolean shown;
 
-  private transient Component windowFocusOwner;
+  // This is package-private to avoid an accessor method.
+  transient Component windowFocusOwner;
   
+  /*
+   * The number used to generate the name returned by getName.
+   */
+  private static transient long next_window_number;
+
   protected class AccessibleAWTWindow extends AccessibleAWTContainer
   {
     public AccessibleRole getAccessibleRole()
@@ -99,7 +105,7 @@ public class Window extends Container implements Accessible
       return AccessibleRole.WINDOW;
     }
     
-    public AccessibleStateSet getAccessibleState()
+    public AccessibleStateSet getAccessibleStateSet()
     {
       AccessibleStateSet states = super.getAccessibleStateSet();
       if (isActive())
@@ -945,4 +951,19 @@ public class Window extends Container implements Accessible
         getToolkit().getSystemEventQueue().postEvent(ce);
       }
   }
+
+  /**
+   * Generate a unique name for this window.
+   *
+   * @return A unique name for this window.
+   */
+  String generateName()
+  {
+    return "win" + getUniqueLong();
+  }
+
+  private static synchronized long getUniqueLong()
+  {
+    return next_window_number++;
+  }
 }
