@@ -854,7 +854,7 @@ public final class Class implements Serializable
    */
   public int getModifiers()
   {
-    return VMClass.getModifiers (this);
+    return VMClass.getModifiers (this, false);
   }
   
   /**
@@ -1113,7 +1113,8 @@ public final class Class implements Serializable
 	  }
 	if (constructor == null)
 	  throw new InstantiationException(getName());
-	if (!Modifier.isPublic(constructor.getModifiers()))
+	if (!Modifier.isPublic(constructor.getModifiers())
+            || !Modifier.isPublic(VMClass.getModifiers(this, true)))
 	  {
 	    final Constructor finalConstructor = constructor;
 	    AccessController.doPrivileged(new PrivilegedAction()
@@ -1132,7 +1133,8 @@ public final class Class implements Serializable
 	  }	    
       }
     int modifiers = constructor.getModifiers();
-    if (!Modifier.isPublic(modifiers))
+    if (!Modifier.isPublic(modifiers)
+        || !Modifier.isPublic(VMClass.getModifiers(this, true)))
       {
 	Class caller = VMStackWalker.getCallingClass();
 	if (caller != null &&
