@@ -321,28 +321,28 @@ public abstract class ClassLoader
   {
     // Have we already loaded this class?
     Class c = findLoadedClass(name);
-    if (c != null)
-      return c;
-
-    // Can the class be loaded by a parent?
-    try
+    if (c == null)
       {
-	if (parent == null)
+	// Can the class be loaded by a parent?
+	try
 	  {
-	    c = VMClassLoader.loadClass(name, resolve);
-	    if (c != null)
-	      return c;
+	    if (parent == null)
+	      {
+		c = VMClassLoader.loadClass(name, resolve);
+		if (c != null)
+		  return c;
+	      }
+	    else
+	      {
+		return parent.loadClass(name, resolve);
+	      }
 	  }
-	else
+	catch (ClassNotFoundException e)
 	  {
-	    return parent.loadClass(name, resolve);
 	  }
+	// Still not found, we have to do it ourself.
+	c = findClass(name);
       }
-    catch (ClassNotFoundException e)
-      {
-      }
-    // Still not found, we have to do it ourself.
-    c = findClass(name);
     if (resolve)
       resolveClass(c);
     return c;
@@ -471,8 +471,9 @@ public abstract class ClassLoader
       domain = StaticData.defaultProtectionDomain;
     if (! initialized)
       throw new SecurityException("attempt to define class from uninitialized class loader");
+    
     Class retval = VMClassLoader.defineClass(this, name, data,
-                                             offset, len, domain);
+					     offset, len, domain);
     loadedClasses.put(retval.getName(), retval);
     return retval;
   }
