@@ -1,5 +1,5 @@
 /* Charset.java -- 
-   Copyright (C) 2002, 2004  Free Software Foundation, Inc.
+   Copyright (C) 2002, 2004, 2005  Free Software Foundation, Inc.
 
 This file is part of GNU Classpath.
 
@@ -38,7 +38,10 @@ exception statement from your version. */
 
 package java.nio.charset;
 
+import gnu.classpath.SystemProperties;
+
 import gnu.java.nio.charset.Provider;
+import gnu.java.nio.charset.iconv.IconvProvider;
 
 import java.io.BufferedReader;
 import java.io.InputStreamReader;
@@ -59,26 +62,18 @@ import java.util.TreeMap;
 /**
  * @author Jesse Rosenstock
  * @since 1.4
+ * @status updated to 1.5
  */
 public abstract class Charset implements Comparable
 {
-  private static CharsetEncoder cachedEncoder;
-  private static CharsetDecoder cachedDecoder;
+  private CharsetEncoder cachedEncoder;
+  private CharsetDecoder cachedDecoder;
  
   /**
    * Charset providers.
    */
   private static CharsetProvider[] providers;
   
-  static
-  {
-    synchronized (Charset.class)
-      {
-        cachedEncoder = null;
-        cachedDecoder = null;
-      }
-  }
-
   private final String canonicalName;
   private final String[] aliases;
   
@@ -92,6 +87,8 @@ public abstract class Charset implements Comparable
             checkName (aliases[i]);
       }
 
+    cachedEncoder = null;
+    cachedDecoder = null;
     this.canonicalName = canonicalName;
     this.aliases = aliases;
   }
@@ -123,6 +120,51 @@ public abstract class Charset implements Comparable
       }
   }
 
+  /**
+   * Returns the system default charset.
+   *
+   * This may be set by the user or VM with the file.encoding
+   * property.
+   */
+  public static Charset defaultCharset()
+  {
+    String encoding;
+    
+    try 
+      {
+	encoding = SystemProperties.getProperty("file.encoding");
+      }
+    catch(SecurityException e)
+      {
+	// Use fallback.
+	encoding = "ISO-8859-1";
+      }
+    catch(IllegalArgumentException e)
+      {
+	// Use fallback.
+	encoding = "ISO-8859-1";
+      }
+
+    try
+      {
+	return forName(encoding);
+      }
+    catch(UnsupportedCharsetException e)
+      {
+	// Ignore.
+      }
+    catch(IllegalCharsetNameException e)
+      {
+	// Ignore.
+      }
+    catch(IllegalArgumentException e)
+      {
+	// Ignore.
+      }
+    
+    throw new IllegalStateException("Can't get default charset!");
+  }
+
   public static boolean isSupported (String charsetName)
   {
     return charsetForName (charsetName) != null;
@@ -163,7 +205,7 @@ public abstract class Charset implements Comparable
   {
     checkName (charsetName);
     Charset cs = null;
-    CharsetProvider[] providers = providers();
+    CharsetProvider[] providers = providers2();
     for (int i = 0; i < providers.length; i++)
       {
         cs = providers[i].charsetForName(charsetName);
@@ -177,7 +219,7 @@ public abstract class Charset implements Comparable
   {
     TreeMap charsets = new TreeMap(String.CASE_INSENSITIVE_ORDER);
 
-    CharsetProvider[] providers = providers();
+    CharsetProvider[] providers = providers2();
     for (int j = 0; j < providers.length; j++)
       {
         for (Iterator i = providers[j].charsets(); i.hasNext(); )
@@ -192,6 +234,12 @@ public abstract class Charset implements Comparable
 
   private static CharsetProvider provider()
   {
+    String useIconv = SystemProperties.getProperty
+      ("gnu.classpath.nio.charset.provider.iconv");
+
+    if (useIconv != null)
+      return IconvProvider.provider();
+
     return Provider.provider();
   }
 
@@ -200,7 +248,7 @@ public abstract class Charset implements Comparable
    * java.nio.charset.spi.CharsetProvider in the resource directory
    * META-INF/services.
    */
-  private static CharsetProvider[] providers()
+  private static CharsetProvider[] providers2()
   {
     if (providers == null)
       {
@@ -296,8 +344,8 @@ public abstract class Charset implements Comparable
                 cachedEncoder = newEncoder ()
                   .onMalformedInput (CodingErrorAction.REPLACE)
                   .onUnmappableCharacter (CodingErrorAction.REPLACE);
-              }
-
+              } else
+ 	        cachedEncoder.reset();
             return cachedEncoder.encode (cb);
           }
       }
@@ -327,7 +375,8 @@ public abstract class Charset implements Comparable
                 cachedDecoder = newDecoder ()
                   .onMalformedInput (CodingErrorAction.REPLACE)
                   .onUnmappableCharacter (CodingErrorAction.REPLACE);
-              }
+              } else
+ 	        cachedDecoder.reset();
 
             return cachedDecoder.decode (bb);
           }
