@@ -38,15 +38,14 @@ exception statement from your version. */
 
 package java.security.cert;
 
+import gnu.classpath.SystemProperties;
+import gnu.java.security.OID;
+
 import java.io.IOException;
-
 import java.math.BigInteger;
-
-import java.security.AccessController;
 import java.security.KeyFactory;
 import java.security.PublicKey;
 import java.security.spec.X509EncodedKeySpec;
-
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
@@ -60,9 +59,6 @@ import java.util.Set;
 
 import javax.security.auth.x500.X500Principal;
 
-import gnu.java.security.OID;
-import gnu.java.security.action.GetPropertyAction;
-
 /**
  * A concrete implementation of {@link CertSelector} for X.509 certificates,
  * which allows a number of criteria to be set when accepting certificates,
@@ -1027,8 +1023,7 @@ public class X509CertSelector implements CertSelector, Cloneable
   public String toString()
   {
     StringBuffer str = new StringBuffer(X509CertSelector.class.getName());
-    GetPropertyAction getProp = new GetPropertyAction("line.separator");
-    String nl = (String) AccessController.doPrivileged(getProp);
+    String nl = SystemProperties.getProperty("line.separator");
     String eol = ";" + nl;
     str.append(" {").append(nl);
     if (cert != null)
