@@ -362,6 +362,14 @@ public abstract class Calendar implements Serializable, Cloneable
    */
   private TimeZone zone;
 
+  /**
+   * This is the default calendar class, that is returned on
+   * java.util.Calendar.getInstance().
+   * XXX - this isn't localized anywhere, is it?
+   * @see java.util.Calendar#getInstance()
+   */
+  private static final String calendarClassName = "java.util.GregorianCalendar";
+
   /**
    * Specifies if the date/time interpretation should be lenient.
    * If the flag is set, a date such as "February 30, 1996" will be
@@ -416,7 +424,7 @@ public abstract class Calendar implements Serializable, Cloneable
   /**
    * The name of the resource bundle. Used only by getBundle()
    */
-  private static final String bundleName = "gnu.java.locale.Calendar";
+  private static final String bundleName = "gnu.java.locale.LocaleInformation";
 
   /**
    * get resource bundle:
@@ -448,12 +456,27 @@ public abstract class Calendar implements Serializable, Cloneable
   {
     this.zone = zone;
     lenient = true;
+    String[] days = { "", "sun", "mon", "tue", "wed", "thu", "fri", "sat" };
 
     ResourceBundle rb = getBundle(locale);
+    String min = (String) rb.getObject("minNumberOfDaysInFirstWeek");
+    String first = (String) rb.getObject("firstDayOfWeek");
+    try
+      {
+	if (min != null)
+	  minimalDaysInFirstWeek = Integer.parseInt(min);
+      }
+    catch (NumberFormatException ex)
+      {
+	minimalDaysInFirstWeek = 1;
+      }
+
+    firstDayOfWeek = 1;
+    if (first != null)
+      for (int i = 0; i < 8; i++)
+	if (days[i].equals(first))
+	  firstDayOfWeek = i;
 
-    firstDayOfWeek = ((Integer) rb.getObject("firstDayOfWeek")).intValue();
-    minimalDaysInFirstWeek = ((Integer) rb.getObject("minimalDaysInFirstWeek"))
-                             .intValue();
     clear();
   }
 
@@ -513,15 +536,9 @@ public abstract class Calendar implements Serializable, Cloneable
       {
 	if (calendarClass == null)
 	  {
-	    ResourceBundle rb = getBundle(locale);
-	    String calendarClassName = rb.getString("calendarClass");
-
-	    if (calendarClassName != null)
-	      {
-		calendarClass = Class.forName(calendarClassName);
-		if (Calendar.class.isAssignableFrom(calendarClass))
-		  cache.put(locale, calendarClass);
-	      }
+	    calendarClass = Class.forName(calendarClassName);
+	    if (Calendar.class.isAssignableFrom(calendarClass))
+	      cache.put(locale, calendarClass);
 	  }
 
 	// GregorianCalendar is by far the most common case. Optimize by 
@@ -706,6 +723,8 @@ public abstract class Calendar implements Serializable, Cloneable
 	isSet[WEEK_OF_YEAR] = false;
 	break;
       case WEEK_OF_MONTH: // pattern 2
+	if (! isSet[DAY_OF_WEEK])
+	  fields[DAY_OF_WEEK] = getFirstDayOfWeek();
 	isSet[YEAR] = true;
 	isSet[MONTH] = true;
 	isSet[DAY_OF_WEEK] = true;
@@ -715,6 +734,8 @@ public abstract class Calendar implements Serializable, Cloneable
 	isSet[WEEK_OF_YEAR] = false;
 	break;
       case DAY_OF_WEEK_IN_MONTH: // pattern 3
+	if (! isSet[DAY_OF_WEEK])
+	  fields[DAY_OF_WEEK] = getFirstDayOfWeek();
 	isSet[YEAR] = true;
 	isSet[MONTH] = true;
 	isSet[DAY_OF_WEEK] = true;
@@ -733,6 +754,8 @@ public abstract class Calendar implements Serializable, Cloneable
 	isSet[DAY_OF_WEEK_IN_MONTH] = false;
 	break;
       case WEEK_OF_YEAR: // pattern 5
+	if (! isSet[DAY_OF_WEEK])
+	  fields[DAY_OF_WEEK] = getFirstDayOfWeek();
 	isSet[YEAR] = true;
 	isSet[DAY_OF_WEEK] = true;
 	isSet[MONTH] = false;
