@@ -1,5 +1,5 @@
 /* Currency.java -- Representation of a currency
-   Copyright (C) 2003, 2004 Free Software Foundation, Inc.
+   Copyright (C) 2003, 2004, 2005  Free Software Foundation, Inc.
 
 This file is part of GNU Classpath.
 
@@ -38,12 +38,11 @@ exception statement from your version. */
 
 package java.util;
 
-import gnu.java.locale.LocaleInformation;
+import gnu.java.locale.LocaleHelper;
 
 import java.io.IOException;
 import java.io.ObjectStreamException;
 import java.io.Serializable;
-import java.util.Properties;
 
 /**
  * Representation of a currency for a particular locale.  Each currency
@@ -94,24 +93,27 @@ public final class Currency
    * @serial the number of fraction digits
    */
   private transient int fractionDigits;
-
-  /**
-   * The currency symbol used when formatting currency strings.
-   * When this field is <code>null</code> the <code>currencyCode</code>
-   * has to be used instead.
-   *
-   * @see #getSymbol()
-   * @see #getSymbol(java.util.Locale)
-   * @serial the currency symbol, or <code>null</code>
-   */
-  private transient String currencySymbol;
   
+  /**
+   * A cached map of country codes
+   * instances to international currency code
+   * <code>String</code>s.  Seperating this
+   * from the <code>Currency</code> instances
+   * ensures we have a common lookup between
+   * the two <code>getInstance()</code> methods.
+   *
+   * @see #getInstance(java.util.Locale)
+   * @serial ignored.
+   */
+  private static transient Map countryMap;
+
   /**
    * A cache of <code>Currency</code> instances to
    * ensure the singleton nature of this class.  The key
-   * is the locale of the currency.
+   * is the international currency code.
    *
    * @see #getInstance(java.util.Locale)
+   * @see #getInstance(java.lang.String) 
    * @see #readResolve()
    * @serial ignored.
    */
@@ -122,6 +124,8 @@ public final class Currency
    */
   static
   {
+    /* Create a hash map for the locale mappings */
+    countryMap = new HashMap();
     /* Create a hash map for the cache */
     cache = new HashMap();
     /* Create the properties object */
@@ -169,7 +173,9 @@ public final class Currency
     /* If there is no country code, return */
     if (countryCode.equals(""))
       {
-        return;
+        throw new
+	  IllegalArgumentException("Invalid (empty) country code for locale:"
+			  	   + loc);
       }
     /* Construct the key for the currency */
     currencyKey = countryCode + ".currency";
@@ -190,9 +196,19 @@ public final class Currency
       }
     /* Retrieve the fraction digits */
     fractionDigits = Integer.parseInt(properties.getProperty(fractionDigitsKey));
-    /* Get currency symbol */
-    currencySymbol =
-      (String) LocaleInformation.getCurrencySymbols().get(currencyCode);
+  }
+
+  /**
+   * Constructor for the "XXX" special case.  This allows
+   * a Currency to be constructed from an assumed good
+   * currency code.
+   *
+   * @param code the code to use.
+   */  
+  private Currency(String code)
+  {
+    currencyCode = code;
+    fractionDigits = -1; /* Pseudo currency */
   }
 
   /**
@@ -249,26 +265,38 @@ public final class Currency
      */
     Currency newCurrency;
 
+    String country = locale.getCountry();
+    if (locale == null || country == null)
+      {
+	throw new
+	  NullPointerException("The locale or its country is null.");
+      }
     /* Attempt to get the currency from the cache */
-    newCurrency = (Currency) cache.get(locale);
-    if (newCurrency == null)
+    String code = (String) countryMap.get(country);
+    if (code == null)
       {
         /* Create the currency for this locale */
-        newCurrency = new Currency (locale);
+        newCurrency = new Currency(locale);
         /* 
          * If the currency code is null, then creation failed
          * and we return null.
          */
-        if (newCurrency.getCurrencyCode() == null)
+	code = newCurrency.getCurrencyCode();
+        if (code == null)
           {
             return null;
           }
         else 
           {
             /* Cache it */
-            cache.put(locale, newCurrency);
+            countryMap.put(country, code);
+	    cache.put(code, newCurrency);
           }
       }
+    else
+      {
+	newCurrency = (Currency) cache.get(code);
+      }
     /* Return the instance */
     return newCurrency;
   }
@@ -288,43 +316,63 @@ public final class Currency
 
     /* 
      * Throw a null pointer exception explicitly if currencyCode is null.
-     * One is not thrown otherwise.  It results in an IllegalArgumentException. 
+     * One is not thrown otherwise.  It results in an
+     * IllegalArgumentException. 
      */
     if (currencyCode == null)
       {
         throw new NullPointerException("The supplied currency code is null.");
       }
-    /* Get all locales */
-    allLocales = Locale.getAvailableLocales();
-    /* Loop through each locale, looking for the code */
-    for (int i = 0;i < allLocales.length; i++)
+    /* Nasty special case to allow an erroneous currency... blame Sun */
+    if (currencyCode.equals("XXX"))
+      return new Currency("XXX");
+    Currency newCurrency = (Currency) cache.get(currencyCode);
+    if (newCurrency == null)
       {
-	Currency testCurrency = getInstance (allLocales[i]);
-	
-	if (testCurrency != null &&
-	    testCurrency.getCurrencyCode().equals(currencyCode))
-	  return testCurrency;
+	/* Get all locales */
+	allLocales = Locale.getAvailableLocales();
+	/* Loop through each locale, looking for the code */
+	for (int i = 0;i < allLocales.length; i++)
+	  {
+	    try
+	      {
+		Currency testCurrency = getInstance (allLocales[i]);
+		if (testCurrency != null &&
+		    testCurrency.getCurrencyCode().equals(currencyCode))
+		  {
+		    return testCurrency;
+		  }
+	      }
+	    catch (IllegalArgumentException exception)
+	      {
+		/* Ignore locales without valid countries */
+	      }
+	  }
+	/* 
+	 * If we get this far, the code is not supported by any of
+	 * our locales.
+	 */
+	throw new IllegalArgumentException("The currency code, " + currencyCode +
+					   ", is not supported.");
+      }
+    else
+      {
+	return newCurrency;
       }
-    /* 
-     * If we get this far, the code is not supported by any of
-     * our locales.
-     */
-    throw new IllegalArgumentException("The currency code, " + currencyCode +
-                                       ", is not supported.");
   }
 
   /**
    * This method returns the symbol which precedes or follows a
-   * value in this particular currency.  In cases where there is no
-   * such symbol for the currency, the ISO 4217 currency
-   * code is returned.
+   * value in this particular currency in the default locale.
+   * In cases where there is no such symbol for the currency,
+   * the ISO 4217 currency code is returned.
    *
    * @return the currency symbol, or the ISO 4217 currency code if
    *         one doesn't exist.
    */
   public String getSymbol()
   {
-    return currencySymbol == null ? getCurrencyCode() : currencySymbol;
+    return getSymbol(Locale.getDefault());
   }
 
   /**
@@ -354,11 +402,8 @@ public final class Currency
    */
   public String getSymbol(Locale locale)
   {
-    /* 
-       We don't currently have the currency symbols, so we always
-       return the currency code.
-    */
-    return getCurrencyCode();
+    return LocaleHelper.getLocalizedString(locale, currencyCode,
+					   "currenciesSymbol", false, true);
   }
 
   /**
