@@ -35,6 +35,7 @@ this exception to your version of the library, but you are not
 obligated to do so.  If you do not wish to do so, delete this
 exception statement from your version. */
 
+
 package javax.swing;
 
 import java.awt.AWTError;
@@ -46,13 +47,11 @@ import java.awt.FlowLayout;
 import java.awt.Frame;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
-import java.io.IOException;
-import java.io.ObjectOutputStream;
+
 import javax.accessibility.Accessible;
 import javax.accessibility.AccessibleContext;
 import javax.accessibility.AccessibleRole;
 import javax.swing.colorchooser.AbstractColorChooserPanel;
-import javax.swing.colorchooser.ColorChooserComponentFactory;
 import javax.swing.colorchooser.ColorSelectionModel;
 import javax.swing.colorchooser.DefaultColorSelectionModel;
 import javax.swing.plaf.ColorChooserUI;
@@ -230,11 +229,11 @@ public class JColorChooser extends JComponent implements Accessible
 
   /**
    * This is a helper method to make the given JDialog block until it is
-   * hidden.
+   * hidden.  This is package-private to avoid an accessor method.
    *
    * @param dialog The JDialog to block.
    */
-  private static void makeModal(JDialog dialog)
+  static void makeModal(JDialog dialog)
   {
     try
       {
