@@ -1,5 +1,5 @@
 /* JComponent.java -- Every component in swing inherits from this class.
-   Copyright (C) 2002, 2004 Free Software Foundation, Inc.
+   Copyright (C) 2002, 2004, 2005  Free Software Foundation, Inc.
 
 This file is part of GNU Classpath.
 
@@ -50,6 +50,7 @@ import java.awt.Image;
 import java.awt.Insets;
 import java.awt.Point;
 import java.awt.Rectangle;
+import java.awt.dnd.DropTarget;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.awt.event.ContainerEvent;
@@ -174,7 +175,7 @@ public abstract class JComponent extends Container implements Serializable
    * @see javax.swing.OverlayLayout
    * @see javax.swing.BoxLayout
    */
-  float alignmentX = 0.0f;
+  float alignmentX = 0.5f;
 
   /**
    * A value between 0.0 and 1.0 indicating the preferred vertical
@@ -189,7 +190,7 @@ public abstract class JComponent extends Container implements Serializable
    * @see javax.swing.OverlayLayout
    * @see javax.swing.BoxLayout
    */
-  float alignmentY = 0.0f;
+  float alignmentY = 0.5f;
 
   /** 
    * The border painted around this component.
@@ -395,6 +396,7 @@ public abstract class JComponent extends Container implements Serializable
   {
     super();
     super.setLayout(new FlowLayout());
+    setDropTarget(new DropTarget());
     defaultLocale = Locale.getDefault();
     debugGraphicsOptions = DebugGraphics.NONE_OPTION;
   }
@@ -427,7 +429,7 @@ public abstract class JComponent extends Container implements Serializable
    * @see #getClientProperties
    * @see #putClientProperty
    */
-  public Object getClientProperty(Object key)
+  public final Object getClientProperty(Object key)
   {
     return getClientProperties().get(key);
   }
@@ -444,7 +446,7 @@ public abstract class JComponent extends Container implements Serializable
    * @see #getClientProperties
    * @see #getClientProperty
    */
-  public void putClientProperty(Object key, Object value)
+  public final void putClientProperty(Object key, Object value)
   {
     getClientProperties().put(key, value);
   }
@@ -1135,9 +1137,9 @@ public abstract class JComponent extends Container implements Serializable
    */
   public JToolTip createToolTip()
   {
-	JToolTip toolTip = new JToolTip();
-	toolTip.setComponent(this);
-	toolTip.setTipText(toolTipText);
+        JToolTip toolTip = new JToolTip();
+        toolTip.setComponent(this);
+        toolTip.setTipText(toolTipText);
     
     return toolTip;
   }
@@ -1171,14 +1173,14 @@ public abstract class JComponent extends Container implements Serializable
       toolTipText = null;
       return;
     }
-		
+                
     // XXX: The tip text doesn't get updated unless you set it to null
     // and then to something not-null. This is consistent with the behaviour
     // of Sun's ToolTipManager.
-			
+                        
     String oldText = toolTipText;
     toolTipText = text;
-		
+                
     if (oldText == null)
       ToolTipManager.sharedInstance().registerComponent(this);
   }
@@ -1301,7 +1303,7 @@ public abstract class JComponent extends Container implements Serializable
   }
 
   /**
-   * Return <code>true<code> if you wish this component to manage its own
+   * Return <code>true</code> if you wish this component to manage its own
    * focus. In particular: if you want this component to be sent
    * <code>TAB</code> and <code>SHIFT+TAB</code> key events, and to not
    * have its children considered as focus transfer targets. If
@@ -1426,7 +1428,7 @@ public abstract class JComponent extends Container implements Serializable
             g2 = doubleBuffer.getGraphics();
             g2.setClip(g.getClipBounds());
           }
-	  
+          
         g2 = getComponentGraphics(g2);
         paintComponent(g2);
         paintBorder(g2);
@@ -1539,7 +1541,23 @@ public abstract class JComponent extends Container implements Serializable
    */
   protected String paramString()
   {
-    return "JComponent";
+    StringBuffer sb = new StringBuffer();
+    sb.append(super.paramString());
+    sb.append(",alignmentX=").append(getAlignmentX());
+    sb.append(",alignmentY=").append(getAlignmentY());
+    sb.append(",border=");
+    if (getBorder() != null)
+      sb.append(getBorder());
+    sb.append(",maximumSize=");
+    if (getMaximumSize() != null)
+      sb.append(getMaximumSize());
+    sb.append(",minimumSize=");
+    if (getMinimumSize() != null)
+      sb.append(getMinimumSize());
+    sb.append(",preferredSize=");
+    if (getPreferredSize() != null)
+      sb.append(getPreferredSize());
+    return sb.toString();
   }
 
   /**
@@ -2255,7 +2273,7 @@ public abstract class JComponent extends Container implements Serializable
 
     this.verifyInputWhenFocusTarget = verifyInputWhenFocusTarget;
     firePropertyChange("verifyInputWhenFocusTarget",
-		       ! verifyInputWhenFocusTarget,
-		       verifyInputWhenFocusTarget);
+                       ! verifyInputWhenFocusTarget,
+                       verifyInputWhenFocusTarget);
   }
 }
