@@ -1,5 +1,5 @@
 /* JList.java --
-   Copyright (C) 2002, 2003, 2004  Free Software Foundation, Inc.
+   Copyright (C) 2002, 2003, 2004, 2005  Free Software Foundation, Inc.
 
 This file is part of GNU Classpath.
 
@@ -129,34 +129,6 @@ public class JList extends JComponent implements Accessible, Scrollable
    */
   public static final int HORIZONTAL_WRAP = 2;
 
-  /** Fired in a PropertyChangeEvent when the "cellRenderer" property changes. */
-  public static final String CELL_RENDERER_PROPERTY_CHANGED = "cellRenderer";
-
-  /** Fired in a PropertyChangeEvent when the "fixedCellHeight" property changes. */
-  public static final String FIXED_CELL_HEIGHT_PROPERTY_CHANGED = "fixedCellHeight";
-
-  /** Fired in a PropertyChangeEvent when the "fixedCellWidth" property changes. */
-  public static final String FIXED_CELL_WIDTH_PROPERTY_CHANGED = "fixedCellWidth";
-
-  /** Fired in a PropertyChangeEvent when the "layoutOrientation" property changes. */
-  public static final String LAYOUT_ORIENTATION_PROPERTY_CHANGED = "layoutOrientation";
-
-  /** Fired in a PropertyChangeEvent when the "model" property changes. */
-  public static final String MODEL_PROPERTY_CHANGED = "model";
-
-  /** Fired in a PropertyChangeEvent when the "prototypeCellValue" property changes. */
-  public static final String PROTOTYPE_CELL_VALUE_PROPERTY_CHANGED = "prototypeCellValue";
-
-  /** Fired in a PropertyChangeEvent when the "selectionBackground" property changes. */
-  public static final String SELECTION_BACKGROUND_PROPERTY_CHANGED = "selectionBackground";
-
-  /** Fired in a PropertyChangeEvent when the "selectionForeground" property changes. */
-  public static final String SELECTION_FOREGROUND_PROPERTY_CHANGED = "selectionForeground";
-
-  /** Fired in a PropertyChangeEvent when the "selectionModel" property changes. */
-  public static final String SELECTION_MODEL_PROPERTY_CHANGED = "selectionModel";
-
-
   /**
    * This property indicates whether "drag and drop" functions are enabled
    * on the list.
@@ -187,7 +159,6 @@ public class JList extends JComponent implements Accessible, Scrollable
    * is one of the integer constants {@link #VERTICAL}, {@link
    * #VERTICAL_WRAP}, or {@link #HORIZONTAL_WRAP}. 
    */
-
   int layoutOrientation;
   
   /** This property holds the data elements displayed by the list. */
@@ -406,9 +377,12 @@ public class JList extends JComponent implements Accessible, Scrollable
    */
   public void setFixedCellHeight(int h)
   {
+    if (fixedCellHeight == h)
+      return;
+
     int old = fixedCellHeight;
     fixedCellHeight = h;
-    firePropertyChange(FIXED_CELL_WIDTH_PROPERTY_CHANGED, old, h);
+    firePropertyChange("fixedCellWidth", old, h);
   }
 
 
@@ -435,17 +409,19 @@ public class JList extends JComponent implements Accessible, Scrollable
    * #prototypeCellValue} property is set, but setting it explicitly
    * overrides the width computed from {@link #prototypeCellValue}.
    *
-   * @see #getFixedCellWidth
+   * @see #getFixedCellHeight
    * @see #getPrototypeCellValue
    */
-  public void setFixedCellWidth(int h)
+  public void setFixedCellWidth(int w)
   {
-    int old = fixedCellHeight;
-    fixedCellHeight = h;
-    firePropertyChange(FIXED_CELL_HEIGHT_PROPERTY_CHANGED, old, h);
+    if (fixedCellWidth == w)
+      return;
+    
+    int old = fixedCellWidth;
+    fixedCellWidth = w;
+    firePropertyChange("fixedCellWidth", old, w);
   }
 
-
   /** 
    * Gets the value of the {@link #visibleRowCount} property. 
    *
@@ -735,9 +711,12 @@ public class JList extends JComponent implements Accessible, Scrollable
    */
   public void setSelectionBackground(Color c)
   {
+    if (selectionBackground == c)
+      return;
+
     Color old = selectionBackground;
     selectionBackground = c;
-    firePropertyChange(SELECTION_BACKGROUND_PROPERTY_CHANGED, old, c);
+    firePropertyChange("selectionBackground", old, c);
     repaint();
   }
 
@@ -758,9 +737,12 @@ public class JList extends JComponent implements Accessible, Scrollable
    */
   public void setSelectionForeground(Color c)
   {
+    if (selectionForeground == c)
+      return;
+
     Color old = selectionForeground;
     selectionForeground = c;
-    firePropertyChange(SELECTION_FOREGROUND_PROPERTY_CHANGED, old, c);
+    firePropertyChange("selectionForeground", old, c);
   }
 
   /**
@@ -871,7 +853,7 @@ public class JList extends JComponent implements Accessible, Scrollable
     
     ListCellRenderer old = cellRenderer;
     cellRenderer = renderer;
-    firePropertyChange(CELL_RENDERER_PROPERTY_CHANGED, old, renderer);
+    firePropertyChange("cellRenderer", old, renderer);
     revalidate();
     repaint();
   }
@@ -907,7 +889,7 @@ public class JList extends JComponent implements Accessible, Scrollable
     if (this.model != null)
       this.model.addListDataListener(listListener);
     
-    firePropertyChange(MODEL_PROPERTY_CHANGED, old, model);
+    firePropertyChange("model", old, model);
     revalidate();
     repaint();
   }
@@ -939,7 +921,7 @@ public class JList extends JComponent implements Accessible, Scrollable
     if (selectionModel != null)
       selectionModel.addListSelectionListener(listListener);
     
-    firePropertyChange(SELECTION_MODEL_PROPERTY_CHANGED, old, model);
+    firePropertyChange("selectionModel", old, model);
     revalidate();
     repaint();
   }
@@ -1019,6 +1001,9 @@ public class JList extends JComponent implements Accessible, Scrollable
    */
   public void setPrototypeCellValue(Object obj)
   {
+    if (prototypeCellValue == obj)
+      return;
+
     Object old = prototypeCellValue;
     Component comp = getCellRenderer()
       .getListCellRendererComponent(this, obj, 0, false, false); 
@@ -1026,7 +1011,7 @@ public class JList extends JComponent implements Accessible, Scrollable
     fixedCellWidth = d.width;
     fixedCellHeight = d.height;
     prototypeCellValue = obj;
-    firePropertyChange(PROTOTYPE_CELL_VALUE_PROPERTY_CHANGED, old, obj);
+    firePropertyChange("prototypeCellValue", old, obj);
   }
 
   public AccessibleContext getAccessibleContext()
@@ -1044,32 +1029,20 @@ public class JList extends JComponent implements Accessible, Scrollable
    */
   public Dimension getPreferredScrollableViewportSize()
   {
-    int vis = getVisibleRowCount();
-    int nrows = getModel() == null ? 0 : getModel().getSize();
-    // FIXME: this is a somewhat arbitrary default, but.. ?
-    Dimension single = new Dimension(10, 10);;
-    Rectangle bounds = null;
 
-    if (vis > nrows)
+    Dimension retVal = getPreferredSize();
+    if (getLayoutOrientation() == VERTICAL)
       {
-        if (fixedCellWidth != -1 && 
-            fixedCellHeight != -1)
+        if (fixedCellHeight != -1)
           {
-            single = new Dimension(fixedCellWidth, fixedCellHeight);
-          }
-        else if (nrows != 0 && getUI() != null)
-          {
-            Rectangle tmp = getUI().getCellBounds(this, 0, 0);
-            if (tmp != null)
-              single = tmp.getSize();
-          }
+            if (fixedCellWidth != -1)
+              {
+                int size = getModel().getSize();
+                retVal = new Dimension(fixedCellWidth, size * fixedCellHeight);
+              } // TODO: add else clause (preferredSize is ok for now)
+          } // TODO: add else clause (preferredSize is ok for now)
       }
-    else if (getUI() != null)
-      {
-        return getUI().getCellBounds(this, 0, vis - 1).getSize();
-      }
-
-    return new Dimension(single.width, single.height * vis);
+    return retVal;
   }
 
   /**
@@ -1208,7 +1181,19 @@ public class JList extends JComponent implements Accessible, Scrollable
    */
   public boolean getScrollableTracksViewportWidth()
   {
-    return false;
+    Component parent = getParent();
+    boolean retVal = false;
+    if (parent instanceof JViewport)
+      {
+        JViewport viewport = (JViewport) parent;
+        Dimension pref = getPreferredSize();
+        if (viewport.getSize().width > pref.width)
+          retVal = true;
+        if ((getLayoutOrientation() == HORIZONTAL_WRAP)
+            && (getVisibleRowCount() <= 0))
+          retVal = true;
+      }
+    return retVal;
   }
 
   /**
@@ -1221,7 +1206,19 @@ public class JList extends JComponent implements Accessible, Scrollable
    */
   public boolean getScrollableTracksViewportHeight()
   {
-    return false;
+    Component parent = getParent();
+    boolean retVal = false;
+    if (parent instanceof JViewport)
+      {
+        JViewport viewport = (JViewport) parent;
+        Dimension pref = getPreferredSize();
+        if (viewport.getSize().height > pref.height)
+          retVal = true;
+        if ((getLayoutOrientation() == VERTICAL_WRAP)
+            && (getVisibleRowCount() <= 0))
+          retVal = true;
+      }
+    return retVal;
   }
 
   public int getAnchorSelectionIndex()
@@ -1312,7 +1309,7 @@ public class JList extends JComponent implements Accessible, Scrollable
    * Returns the layout orientation.
    *
    * @return the orientation, one of <code>JList.VERTICAL</code>,
-   * </code>JList.VERTICAL_WRAP</code> and <code>JList.HORIZONTAL_WRAP</code>
+   * <code>JList.VERTICAL_WRAP</code> and <code>JList.HORIZONTAL_WRAP</code>
    *
    * @since 1.4
    */
@@ -1325,7 +1322,7 @@ public class JList extends JComponent implements Accessible, Scrollable
    * Sets the layout orientation.
    *
    * @param orientation the orientation to set, one of <code>JList.VERTICAL</code>,
-   * </code>JList.VERTICAL_WRAP</code> and <code>JList.HORIZONTAL_WRAP</code>
+   * <code>JList.VERTICAL_WRAP</code> and <code>JList.HORIZONTAL_WRAP</code>
    *
    * @since 1.4
    */
