@@ -1,5 +1,5 @@
 /* JToolBar.java --
-   Copyright (C) 2002, 2004 Free Software Foundation, Inc.
+   Copyright (C) 2002, 2004, 2005  Free Software Foundation, Inc.
 
 This file is part of GNU Classpath.
 
@@ -50,6 +50,7 @@ import javax.accessibility.Accessible;
 import javax.accessibility.AccessibleContext;
 import javax.accessibility.AccessibleRole;
 import javax.accessibility.AccessibleStateSet;
+import javax.swing.JButton;
 import javax.swing.plaf.ToolBarUI;
 
 /**
@@ -378,21 +379,6 @@ public class JToolBar extends JComponent implements SwingConstants, Accessible
   /** The orientation of the JToolBar. */
   private int orientation = HORIZONTAL;
 
-  /** Fired in a PropertyChangeEvent when the orientation property changes. */
-  public static final String ORIENTATION_CHANGED_PROPERTY = "orientation";
-
-  /** Fired in a PropertyChangeEvent when the floatable property changes. */
-  public static final String FLOATABLE_CHANGED_PROPERTY = "floatable";
-
-  /** Fired in a PropertyChangeEvent when the borderPainted property changes. */
-  public static final String BORDER_PAINTED_CHANGED_PROPERTY = "borderPainted";
-
-  /** Fired in a PropertyChangeEvent when the margin property changes. */
-  public static final String MARGIN_CHANGED_PROPERTY = "margin";
-
-  /** Fired in a PropertyChangeEvent when the rollover property changes. */
-  public static final String ROLLOVER_CHANGED_PROPERTY = "rollover";
-
   /**
    * This method creates a new JToolBar object with horizontal orientation
    * and no name.
@@ -519,7 +505,7 @@ public class JToolBar extends JComponent implements SwingConstants, Accessible
     if (b != rollover)
       {
 	rollover = b;
-	firePropertyChange(ROLLOVER_CHANGED_PROPERTY, ! rollover, rollover);
+	firePropertyChange("rollover", ! rollover, rollover);
 	revalidate();
 	repaint();
       }
@@ -595,7 +581,7 @@ public class JToolBar extends JComponent implements SwingConstants, Accessible
       {
 	Insets oldMargin = this.margin;
 	this.margin = margin;
-	firePropertyChange(MARGIN_CHANGED_PROPERTY, oldMargin, this.margin);
+	firePropertyChange("margin", oldMargin, this.margin);
 	revalidate();
 	repaint();
       }
@@ -622,7 +608,7 @@ public class JToolBar extends JComponent implements SwingConstants, Accessible
     if (painted != paintBorder)
       {
 	paintBorder = painted;
-	firePropertyChange(BORDER_PAINTED_CHANGED_PROPERTY, ! paintBorder,
+	firePropertyChange("borderPainted", ! paintBorder,
 	                   paintBorder);
 	repaint();
       }
@@ -649,7 +635,7 @@ public class JToolBar extends JComponent implements SwingConstants, Accessible
     if (floatable != this.floatable)
       {
 	this.floatable = floatable;
-	firePropertyChange(FLOATABLE_CHANGED_PROPERTY, ! floatable, floatable);
+	firePropertyChange("floatable", ! floatable, floatable);
       }
   } // setFloatable()
 
@@ -692,8 +678,7 @@ public class JToolBar extends JComponent implements SwingConstants, Accessible
       {
 	int oldOrientation = this.orientation;
 	this.orientation = orientation;
-	firePropertyChange(ORIENTATION_CHANGED_PROPERTY, oldOrientation,
-	                   this.orientation);
+	firePropertyChange("orientation", oldOrientation, this.orientation);
 	revalidate();
 	repaint();
       }
@@ -758,6 +743,15 @@ public class JToolBar extends JComponent implements SwingConstants, Accessible
   {
     // XXX: Sun says disable button but test cases show otherwise.
     super.addImpl(component, constraints, index);
+
+    // if we added a Swing Button then adjust this a little
+    if (component instanceof AbstractButton)
+      {
+        AbstractButton b = (AbstractButton) component;
+        b.setRolloverEnabled(rollover);
+        b.updateUI();
+      }
+
   } // addImpl()
 
   /**
