@@ -1,5 +1,5 @@
 /* UIManager.java -- 
-   Copyright (C) 2002, 2003, 2004  Free Software Foundation, Inc.
+   Copyright (C) 2002, 2003, 2004, 2005  Free Software Foundation, Inc.
 
 This file is part of GNU Classpath.
 
@@ -44,6 +44,8 @@ import java.awt.Font;
 import java.awt.Insets;
 import java.beans.PropertyChangeListener;
 import java.io.Serializable;
+import java.util.Locale;
+
 import javax.swing.border.Border;
 import javax.swing.plaf.ComponentUI;
 import javax.swing.plaf.metal.MetalLookAndFeel;
@@ -81,7 +83,26 @@ public class UIManager implements Serializable
   static LookAndFeel[] aux_installed;
   
   static LookAndFeel look_and_feel = new MetalLookAndFeel();
-    
+
+  static
+  {
+    String defaultlaf = System.getProperty("swing.defaultlaf");
+    try {
+      if (defaultlaf != null)
+        {
+          Class lafClass = Class.forName(defaultlaf);
+          LookAndFeel laf = (LookAndFeel) lafClass.newInstance();
+          setLookAndFeel(laf);
+        }
+    }
+    catch (Exception ex)
+      {
+        System.err.println("cannot initialize Look and Feel: " + defaultlaf);
+        System.err.println("errot: " + ex.getMessage());
+        System.err.println("falling back to Metal Look and Feel");
+      }
+  }
+
   public UIManager()
   {
     // Do nothing here.
@@ -158,10 +179,43 @@ public class UIManager implements Serializable
   }
 
   public static  LookAndFeel[] getAuxiliaryLookAndFeels()
-  {	return aux_installed;    }
+  {
+    return aux_installed;
+  }
 
   public static  Object get(Object key)
-  {	return getLookAndFeel().getDefaults().get(key);    }
+  {
+    return getLookAndFeel().getDefaults().get(key);
+  }
+
+  public static  Object get(Object key, Locale locale)
+  {
+    return getLookAndFeel().getDefaults().get(key ,locale);
+  }
+
+  /**
+   * Returns a boolean value from the defaults table,
+   * <code>false</code> if key is not present.
+   *
+   * @since 1.4
+   */
+  public static boolean getBoolean(Object key)
+  {
+    Boolean value = (Boolean) getLookAndFeel().getDefaults().get(key);
+    return value != null ? value.booleanValue() : false;
+  }
+  
+  /**
+   * Returns a boolean value from the defaults table,
+   * <code>false</code> if key is not present.
+   *
+   * @since 1.4
+   */
+  public static boolean getBoolean(Object key, Locale locale)
+  {
+    Boolean value = (Boolean) getLookAndFeel().getDefaults().get(key, locale);
+    return value != null ? value.booleanValue() : false;
+  }
     
   /**
    * Returns a border from the defaults table. 
@@ -171,6 +225,16 @@ public class UIManager implements Serializable
     return (Border) getLookAndFeel().getDefaults().get(key);
   }
     
+  /**
+   * Returns a border from the defaults table.
+   *
+   * @since 1.4
+   */
+  public static Border getBorder(Object key, Locale locale)
+  {
+    return (Border) getLookAndFeel().getDefaults().get(key, locale);
+  }
+    
   /**
    * Returns a drawing color from the defaults table. 
    */
@@ -179,6 +243,14 @@ public class UIManager implements Serializable
     return (Color) getLookAndFeel().getDefaults().get(key);
   }
 
+  /**
+   * Returns a drawing color from the defaults table. 
+   */
+  public static  Color getColor(Object key, Locale locale)
+  {
+    return (Color) getLookAndFeel().getDefaults().get(key);
+  }
+
   /**
    * this string can be passed to Class.forName()
    */
@@ -203,6 +275,14 @@ public class UIManager implements Serializable
     return (Dimension) getLookAndFeel().getDefaults().get(key);
   }
 
+  /**
+   * Returns a dimension from the defaults table. 
+   */
+  public static Dimension getDimension(Object key, Locale locale)
+  {
+    return (Dimension) getLookAndFeel().getDefaults().get(key, locale);
+  }
+
   /**
    * Retrieves a font from the defaults table of the current
    * LookAndFeel.
@@ -216,6 +296,19 @@ public class UIManager implements Serializable
     return (Font) getLookAndFeel().getDefaults().get(key);
   }
 
+  /**
+   * Retrieves a font from the defaults table of the current
+   * LookAndFeel.
+   *
+   * @param key an Object that specifies the font. Typically,
+   *        this is a String such as
+   *        <code>TitledBorder.font</code>.
+   */
+  public static Font getFont(Object key, Locale locale)
+  {
+    return (Font) getLookAndFeel().getDefaults().get(key ,locale);
+  }
+
   /**
    * Returns an Icon from the defaults table.
    */
@@ -224,6 +317,14 @@ public class UIManager implements Serializable
     return (Icon) getLookAndFeel().getDefaults().get(key);
   }
   
+  /**
+   * Returns an Icon from the defaults table.
+   */
+  public static Icon getIcon(Object key, Locale locale)
+  {
+    return (Icon) getLookAndFeel().getDefaults().get(key, locale);
+  }
+  
   /**
    * Returns an Insets object from the defaults table.
    */
@@ -232,6 +333,14 @@ public class UIManager implements Serializable
     return (Insets) getLookAndFeel().getDefaults().getInsets(key);
   }
 
+  /**
+   * Returns an Insets object from the defaults table.
+   */
+  public static Insets getInsets(Object key, Locale locale)
+  {
+    return (Insets) getLookAndFeel().getDefaults().getInsets(key, locale);
+  }
+
   public static LookAndFeelInfo[] getInstalledLookAndFeels()
   {
     return installed;
@@ -245,6 +354,14 @@ public class UIManager implements Serializable
     return x.intValue();
   }
 
+  public static int getInt(Object key, Locale locale)
+  {
+    Integer x = (Integer) getLookAndFeel().getDefaults().get(key, locale);
+    if (x == null)
+      return 0;
+    return x.intValue();
+  }
+
   public static LookAndFeel getLookAndFeel()
   {
     return look_and_feel;
@@ -267,6 +384,14 @@ public class UIManager implements Serializable
     return (String) getLookAndFeel().getDefaults().get(key);
   }
   
+  /**
+   * Returns a string from the defaults table.
+   */
+  public static String getString(Object key, Locale locale)
+  {
+    return (String) getLookAndFeel().getDefaults().get(key, locale);
+  }
+  
   /**
    * Returns the name of the LookAndFeel class that implements the
    * native systems look and feel if there is one, otherwise the name
