@@ -1,5 +1,5 @@
 /* BasicComboBoxUI.java --
-   Copyright (C) 2004  Free Software Foundation, Inc.
+   Copyright (C) 2004, 2005  Free Software Foundation, Inc.
 
 This file is part of GNU Classpath.
 
@@ -160,17 +160,22 @@ public class BasicComboBoxUI extends ComboBoxUI
   private Color highlight;
   private Color lightHighlight;
 
-  /* Size of the largest item in the comboBox */
-  private Dimension largestItemSize;
+  /* Size of the largest item in the comboBox
+   * This is package-private to avoid an accessor method.
+   */
+  Dimension largestItemSize;
 
   // It seems that JComboBox doesn't have a border set explicitely. So we just
   // paint the border everytime combo box is displayed. 
 
-  /* border insets for this JComboBox*/
-  private static final Insets borderInsets = new Insets(2, 2, 2, 2);
+  /* border insets for this JComboBox
+   * This is package-private to avoid an accessor method. */
+  static final Insets borderInsets = new Insets(2, 2, 2, 2);
 
   // Width of the arrow button  
-  private static int arrowButtonWidth = 15;
+  // This is package-private to avoid an accessor method.
+  // FIXME: has wrong name for a constant.
+  static final int arrowButtonWidth = 15;
 
   // FIXME: This fields aren't used anywhere at this moment.
   protected Dimension cachedMinimumSize;
@@ -1146,7 +1151,7 @@ public class BasicComboBoxUI extends ComboBoxUI
      */
     public void propertyChange(PropertyChangeEvent e)
     {
-      if (e.getPropertyName().equals(JComboBox.ENABLED_CHANGED_PROPERTY))
+      if (e.getPropertyName().equals("enabled"))
         {
 	  arrowButton.setEnabled(comboBox.isEnabled());
 
@@ -1154,7 +1159,7 @@ public class BasicComboBoxUI extends ComboBoxUI
 	    comboBox.getEditor().getEditorComponent().setEnabled(comboBox
 	                                                         .isEnabled());
         }
-      else if (e.getPropertyName().equals(JComboBox.EDITABLE_CHANGED_PROPERTY))
+      else if (e.getPropertyName().equals("editable"))
         {
 	  if (comboBox.isEditable())
 	    {
@@ -1170,7 +1175,7 @@ public class BasicComboBoxUI extends ComboBoxUI
 	  comboBox.revalidate();
 	  comboBox.repaint();
         }
-      else if (e.getPropertyName().equals(JComboBox.MODEL_CHANGED_PROPERTY))
+      else if (e.getPropertyName().equals("dataModel"))
         {
 	  // remove ListDataListener from old model and add it to new model
 	  ComboBoxModel oldModel = (ComboBoxModel) e.getOldValue();
