@@ -1,5 +1,5 @@
 /* BasicMenuItemUI.java --
-   Copyright (C) 2002, 2004  Free Software Foundation, Inc.
+   Copyright (C) 2002, 2004, 2005  Free Software Foundation, Inc.
 
 This file is part of GNU Classpath.
 
@@ -46,26 +46,21 @@ import java.awt.FontMetrics;
 import java.awt.Graphics;
 import java.awt.Insets;
 import java.awt.Rectangle;
-import java.awt.Stroke;
-import java.awt.event.InputEvent;
 import java.awt.event.KeyEvent;
 import java.awt.event.MouseEvent;
 import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;
 import java.util.ArrayList;
-import java.util.Vector;
-import javax.swing.AbstractButton;
-import javax.swing.ButtonModel;
+
 import javax.swing.Icon;
-import javax.swing.JCheckBoxMenuItem;
 import javax.swing.JComponent;
 import javax.swing.JMenu;
 import javax.swing.JMenuItem;
 import javax.swing.JPopupMenu;
-import javax.swing.JRadioButtonMenuItem;
 import javax.swing.KeyStroke;
 import javax.swing.MenuElement;
 import javax.swing.MenuSelectionManager;
+import javax.swing.SwingConstants;
 import javax.swing.SwingUtilities;
 import javax.swing.UIDefaults;
 import javax.swing.UIManager;
@@ -77,7 +72,6 @@ import javax.swing.event.MouseInputListener;
 import javax.swing.plaf.ComponentUI;
 import javax.swing.plaf.MenuItemUI;
 
-
 /**
  * UI Delegate for JMenuItem.
  */
@@ -152,7 +146,7 @@ public class BasicMenuItemUI extends MenuItemUI
   protected Color selectionBackground;
 
   /**
-   * Color of the background that is used when menu item is selected.
+   * Color of the text that is used when menu item is selected.
    */
   protected Color selectionForeground;
 
@@ -276,6 +270,11 @@ public class BasicMenuItemUI extends MenuItemUI
   public MenuElement[] getPath()
   {
     ArrayList path = new ArrayList();
+
+    // Path to menu should also include its popup menu.
+    if (menuItem instanceof JMenu)
+      path.add(((JMenu) menuItem).getPopupMenu());
+
     Component c = menuItem;
     while (c instanceof MenuElement)
       {
@@ -305,19 +304,6 @@ public class BasicMenuItemUI extends MenuItemUI
   protected Dimension getPreferredMenuItemSize(JComponent c, Icon checkIcon,
                                                Icon arrowIcon,
                                                int defaultTextIconGap)
-  {
-    // FIXME: Need to implement.
-    return null;
-  }
-
-  /**
-   * Returns preferred size of the given component
-   *
-   * @param c component for which to return preferred size
-   *
-   * @return $Dimension$ preferred size for the given component
-   */
-  public Dimension getPreferredSize(JComponent c)
   {
     JMenuItem m = (JMenuItem) c;
     Dimension d = BasicGraphicsUtils.getPreferredButtonSize(m,
@@ -361,10 +347,17 @@ public class BasicMenuItemUI extends MenuItemUI
   }
 
   /**
-   * DOCUMENT ME!
+   * Returns preferred size of the given component
    *
-   * @return $returnType$ DOCUMENT ME!
+   * @param c component for which to return preferred size
+   *
+   * @return $Dimension$ preferred size for the given component
    */
+  public Dimension getPreferredSize(JComponent c)
+  {
+    return getPreferredMenuItemSize(c, checkIcon, arrowIcon, defaultTextIconGap);
+  }
+
   protected String getPropertyPrefix()
   {
     return null;
@@ -400,6 +393,9 @@ public class BasicMenuItemUI extends MenuItemUI
     selectionBackground = defaults.getColor("MenuItem.selectionBackground");
     selectionForeground = defaults.getColor("MenuItem.selectionForeground");
     acceleratorDelimiter = defaults.getString("MenuItem.acceleratorDelimiter");
+
+    menuItem.setHorizontalTextPosition(SwingConstants.TRAILING);
+    menuItem.setHorizontalAlignment(SwingConstants.LEADING);
   }
 
   /**
@@ -416,6 +412,7 @@ public class BasicMenuItemUI extends MenuItemUI
   protected void installListeners()
   {
     menuItem.addMouseListener(mouseInputListener);
+    menuItem.addMouseMotionListener(mouseInputListener);
     menuItem.addMenuDragMouseListener(menuDragMouseListener);
     menuItem.addMenuKeyListener(menuKeyListener);
     menuItem.addPropertyChangeListener(propertyChangeListener);
@@ -433,6 +430,7 @@ public class BasicMenuItemUI extends MenuItemUI
     super.installUI(c);
     menuItem = (JMenuItem) c;
     installDefaults();
+    installComponents(menuItem);
     installListeners();
   }
 
@@ -516,7 +514,7 @@ public class BasicMenuItemUI extends MenuItemUI
       {
 	if (m.isContentAreaFilled())
 	  {
-	    g.setColor(m.getBackground().darker());
+	    g.setColor(selectionBackground);
 	    g.fillRect(br.x, br.y, br.width, br.height);
 	  }
       }
@@ -529,6 +527,7 @@ public class BasicMenuItemUI extends MenuItemUI
 	  }
       }
 
+    // If this menu item is a JCheckBoxMenuItem then paint check icon
     if (checkIcon != null)
       {
 	SwingUtilities.layoutCompoundLabel(m, fm, null, checkIcon, vertAlign,
@@ -543,6 +542,7 @@ public class BasicMenuItemUI extends MenuItemUI
 	vr.x = cr.x + cr.width + defaultTextIconGap;
       }
 
+    // if this is a submenu, then paint arrow icon to indicate it.
     if (arrowIcon != null && (c instanceof JMenu))
       {
 	if (! ((JMenu) c).isTopLevelMenu())
@@ -556,27 +556,16 @@ public class BasicMenuItemUI extends MenuItemUI
       }
 
     // paint text and user menu icon if it exists	     
-    SwingUtilities.layoutCompoundLabel(c, fm, m.getText(), m.getIcon(),
+    Icon i = m.getIcon();
+    SwingUtilities.layoutCompoundLabel(c, fm, m.getText(), i,
                                        vertAlign, horAlign, vertTextPos,
                                        horTextPos, vr, ir, tr,
                                        defaultTextIconGap);
+    if (i != null)
+      i.paintIcon(c, g, ir.x, ir.y);
 
     paintText(g, m, tr, m.getText());
 
-    // paint icon
-    // FIXME: should paint different icon at different button state's.
-    // i.e disabled icon when button is disabled.. etc.
-
-    /*
-    Icon i = m.getIcon();
-    if (i != null)
-      {
-         int x = ir.x;
-         int y = ir.y;
-         i.paintIcon(c, g, x, y);
-      }
-    */
-
     // paint accelerator    
     String acceleratorText = "";
 
@@ -612,10 +601,37 @@ public class BasicMenuItemUI extends MenuItemUI
     Font f = menuItem.getFont();
     g.setFont(f);
     FontMetrics fm = g.getFontMetrics(f);
-    g.setColor(menuItem.getForeground());
 
-    BasicGraphicsUtils.drawString(g, text, 0, textRect.x,
-                                  textRect.y + fm.getAscent());
+    if (text != null && ! text.equals(""))
+      {
+	if (menuItem.isEnabled())
+          {
+            /* Menu item is considered to be highlighted when it is selected.
+               It is considered to be selected if menu item is inside some menu
+               and is armed or if it is both armed and pressed */
+            if (menuItem.getModel().isArmed()
+                && (menuItem.getParent() instanceof MenuElement
+                    || menuItem.getModel().isPressed()))
+              g.setColor(selectionForeground);
+            else
+              g.setColor(menuItem.getForeground());
+          }
+	else
+	  // FIXME: should fix this to use 'disabledForeground', but its
+	  // default value in BasicLookAndFeel is null.	  
+	  g.setColor(Color.gray);
+
+	int mnemonicIndex = menuItem.getDisplayedMnemonicIndex();
+
+	if (mnemonicIndex != -1)
+	  BasicGraphicsUtils.drawStringUnderlineCharAt(g, text, mnemonicIndex,
+	                                               textRect.x,
+	                                               textRect.y
+	                                               + fm.getAscent());
+	else
+	  BasicGraphicsUtils.drawString(g, text, 0, textRect.x,
+	                                textRect.y + fm.getAscent());
+      }
   }
 
   /**
@@ -682,6 +698,7 @@ public class BasicMenuItemUI extends MenuItemUI
   {
     uninstallListeners();
     uninstallDefaults();
+    uninstallComponents(menuItem);
     menuItem = null;
   }
 
@@ -751,7 +768,14 @@ public class BasicMenuItemUI extends MenuItemUI
   {
     g.setFont(acceleratorFont);
     FontMetrics fm = g.getFontMetrics(acceleratorFont);
-    g.setColor(acceleratorForeground);
+
+    if (menuItem.isEnabled())
+      g.setColor(acceleratorForeground);
+    else
+      // FIXME: should fix this to use 'disabledForeground', but its
+      // default value in BasicLookAndFeel is null.
+      g.setColor(Color.gray);
+
     BasicGraphicsUtils.drawString(g, acceleratorText, 0, acceleratorRect.x,
                                   acceleratorRect.y + fm.getAscent());
   }
@@ -859,14 +883,17 @@ public class BasicMenuItemUI extends MenuItemUI
      */
     public void mouseReleased(MouseEvent e)
     {
-      Rectangle size = menuItem.getBounds(); //this.getParent().getSize();
+      Rectangle size = menuItem.getBounds();
+      MenuSelectionManager manager = MenuSelectionManager.defaultManager();
       if (e.getX() > 0 && e.getX() < size.width && e.getY() > 0
           && e.getY() < size.height)
         {
-	  MenuSelectionManager manager = MenuSelectionManager.defaultManager();
 	  manager.clearSelectedPath();
-	  menuItem.doClick(0);
+	  menuItem.doClick();
         }
+
+      else
+	manager.processMouseEvent(e);
     }
   }
 
@@ -882,6 +909,8 @@ public class BasicMenuItemUI extends MenuItemUI
      */
     public void menuDragMouseDragged(MenuDragMouseEvent e)
     {
+      MenuSelectionManager manager = MenuSelectionManager.defaultManager();
+      manager.setSelectedPath(e.getPath());
     }
 
     /**
@@ -892,6 +921,8 @@ public class BasicMenuItemUI extends MenuItemUI
      */
     public void menuDragMouseEntered(MenuDragMouseEvent e)
     {
+      MenuSelectionManager manager = MenuSelectionManager.defaultManager();
+      manager.setSelectedPath(e.getPath());
     }
 
     /**
@@ -912,6 +943,13 @@ public class BasicMenuItemUI extends MenuItemUI
      */
     public void menuDragMouseReleased(MenuDragMouseEvent e)
     {
+      MenuElement[] path = e.getPath();
+
+      if (path[path.length - 1] instanceof JMenuItem)
+	((JMenuItem) path[path.length - 1]).doClick();
+
+      MenuSelectionManager manager = MenuSelectionManager.defaultManager();
+      manager.clearSelectedPath();
     }
   }
 
@@ -963,6 +1001,8 @@ public class BasicMenuItemUI extends MenuItemUI
      */
     public void propertyChange(PropertyChangeEvent evt)
     {
+      menuItem.revalidate();
+      menuItem.repaint();
     }
   }
 }
