@@ -1,5 +1,5 @@
 /* AbstractDocument.java --
-   Copyright (C) 2002, 2004 Free Software Foundation, Inc.
+   Copyright (C) 2002, 2004, 2005  Free Software Foundation, Inc.
 
 This file is part of GNU Classpath.
 
@@ -40,10 +40,10 @@ package javax.swing.text;
 
 import java.io.PrintStream;
 import java.io.Serializable;
-import java.util.Collections;
 import java.util.Dictionary;
 import java.util.Enumeration;
 import java.util.EventListener;
+import java.util.Hashtable;
 import java.util.Vector;
 
 import javax.swing.event.DocumentEvent;
@@ -72,7 +72,10 @@ public abstract class AbstractDocument
   Content content;
   AttributeContext context;
   DocumentFilter documentFilter;
-  
+
+  /** The documents properties. */
+  Dictionary properties;
+
   protected EventListenerList listenerList = new EventListenerList();
 
   protected AbstractDocument(Content doc)
@@ -176,7 +179,11 @@ public abstract class AbstractDocument
 
   public Dictionary getDocumentProperties()
   {
-    return null;
+    // FIXME: make me thread-safe
+    if (properties == null)
+      properties = new Hashtable();
+
+    return properties;
   }
 
   public Position getEndPosition()
@@ -202,7 +209,12 @@ public abstract class AbstractDocument
 
   public Object getProperty(Object key)
   {
-    return null;
+    // FIXME: make me thread-safe
+    Object value = null;
+    if (properties != null)
+      value = properties.get(key);
+
+    return value;
   }
 
   public Element[] getRootElements()
@@ -259,6 +271,11 @@ public abstract class AbstractDocument
 
   public void putProperty(Object key, Object value)
   {
+    // FIXME: make me thread-safe
+    if (properties == null)
+      properties = new Hashtable();
+
+    properties.put(key, value);
   }
 
   public void readLock()
@@ -367,6 +384,8 @@ public abstract class AbstractDocument
 
   public void setDocumentProperties(Dictionary x)
   {
+    // FIXME: make me thread-safe
+    properties = x;
   }
 
   protected void writeLock()
