@@ -56,9 +56,9 @@ public interface AttributeSet
   static interface ParagraphAttribute
   {
   }
-  
-  static Object NameAttribute = StyleConstants.NameAttribute;
-  static Object ResolveAttribute = StyleConstants.ResolveAttribute;
+
+  Object NameAttribute = StyleConstants.NameAttribute;
+  Object ResolveAttribute = StyleConstants.ResolveAttribute;
 
   boolean containsAttribute(Object name, Object value);
   boolean containsAttributes(AttributeSet attributes);
