@@ -1,5 +1,5 @@
 /* JTextComponent.java --
-   Copyright (C) 2002, 2004  Free Software Foundation, Inc.
+   Copyright (C) 2002, 2004, 2005  Free Software Foundation, Inc.
 
 This file is part of GNU Classpath.
 
@@ -302,7 +302,7 @@ public abstract class JTextComponent extends JComponent
    * report</a>, a pair of private classes wraps a {@link
    * javax.swing.text.Keymap} in the new {@link InputMap} / {@link
    * ActionMap} interfaces, such that old Keymap-using code can make use of
-   * the new framework.</p>
+   * the new framework.
    *
    * <p>A little bit of experimentation with these classes reveals the following
    * structure:
@@ -843,7 +843,7 @@ public abstract class JTextComponent extends JComponent
    * <code>b</code>, if there exists a provided action <code>a</code> such
    * that <code>a.getValue(Action.NAME) == b.ActionName</code> then an
    * entry is added to the Keymap mapping <code>b</code> to
-   * </code>a</code>.
+   * <code>a</code>.
    *
    * @param map The Keymap to add new mappings to
    * @param bindings The set of bindings to add to the Keymap
@@ -883,7 +883,8 @@ public abstract class JTextComponent extends JComponent
     return getUI().getEditorKit(this).getActions();
   }
     
-  private Document doc;
+  // This is package-private to avoid an accessor method.
+  Document doc;
   private Caret caret;
   private Highlighter highlighter;
   private Color caretColor;
@@ -894,11 +895,30 @@ public abstract class JTextComponent extends JComponent
   private Insets margin;
   private boolean dragEnabled;
 
+  /** Issues repaint request on document changes. */
+  private DocumentListener repaintListener;
+
   /**
    * Creates a new <code>JTextComponent</code> instance.
    */
   public JTextComponent()
   {
+    repaintListener = new DocumentListener()
+      {
+	public void changedUpdate(DocumentEvent ev)
+	{
+	  repaint();
+	}
+	public void insertUpdate(DocumentEvent ev)
+	{
+	  repaint();
+	}
+	public void removeUpdate(DocumentEvent ev)
+	{
+	  repaint();
+	}
+      };
+
     Keymap defkeymap = getKeymap(DEFAULT_KEYMAP);
     boolean creatingKeymap = false;
     if (defkeymap == null)
@@ -932,6 +952,13 @@ public abstract class JTextComponent extends JComponent
   {
     Document oldDoc = doc;
     doc = newDoc;
+
+    // setup document listener
+    if (oldDoc != null)
+      oldDoc.removeDocumentListener(repaintListener);
+    if (newDoc != null)
+      newDoc.addDocumentListener(repaintListener);
+
     firePropertyChange("document", oldDoc, newDoc);
     revalidate();
     repaint();
@@ -943,7 +970,7 @@ public abstract class JTextComponent extends JComponent
   }
 
   /**
-   * Get the <code>AccessibleContext<code> of this object.
+   * Get the <code>AccessibleContext</code> of this object.
    *
    * @return an <code>AccessibleContext</code> object
    */
@@ -1467,6 +1494,11 @@ public abstract class JTextComponent extends JComponent
     dragEnabled = enabled;
   }
 
+  public int viewToModel(Point pt)
+  {
+    return getUI().viewToModel(this, pt);
+  }
+
   public void copy()
   {
     doTransferAction("copy", TransferHandler.getCopyAction());
