@@ -50,62 +50,61 @@ exception statement from your version. */
  * Signature: (Ljava/lang/Class;)Z
  */
 JNIEXPORT jboolean JNICALL
-Java_java_io_VMObjectStreamClass_hasClassInitializer(JNIEnv * env,
-						 jclass vmosklass
-						 __attribute__ ((__unused__)),
-						 jclass klass )
+Java_java_io_VMObjectStreamClass_hasClassInitializer (JNIEnv * env,
+						      jclass vmosklass
+						      __attribute__ ((__unused__)), jclass klass)
 {
-  jmethodID mid = (*env)->GetStaticMethodID(env, klass, "<clinit>", "()V");
+  jmethodID mid = (*env)->GetStaticMethodID (env, klass, "<clinit>", "()V");
   if (mid == NULL)
     {
-      (*env)->ExceptionClear(env);
+      (*env)->ExceptionClear (env);
       return JNI_FALSE;
     }
   return JNI_TRUE;
 }
 
-static void throwInternalError(JNIEnv *env)
+static void
+throwInternalError (JNIEnv * env)
 {
   jclass internalErrorClass;
   jthrowable previousException, newException;
   jmethodID initException, getMessageID, initCauseID;
   jstring message;
 
-  internalErrorClass = (*env)->FindClass(env, "java/lang/InternalError");
+  internalErrorClass = (*env)->FindClass (env, "java/lang/InternalError");
   /** Just give up if this also fails. */
   if (internalErrorClass == NULL)
     return;
 
-  previousException = (*env)->ExceptionOccurred(env);
+  previousException = (*env)->ExceptionOccurred (env);
 
   if (previousException == NULL)
     {
-      (*env)->ThrowNew(env, internalErrorClass, "Unknown error raised by the VM");
+      (*env)->ThrowNew (env, internalErrorClass,
+			"Unknown error raised by the VM");
       return;
     }
-  
+
   initException = (*env)->GetMethodID
     (env, internalErrorClass, "<init>", "(Ljava/lang/String;)V");
   getMessageID = (*env)->GetMethodID
-    (env, (*env)->GetObjectClass(env, previousException),
+    (env, (*env)->GetObjectClass (env, previousException),
      "getMessage", "()Ljava/lang/String;");
   initCauseID = (*env)->GetMethodID
     (env, internalErrorClass, "initCause", "(Ljava/lang/Throwable;)V");
 
-  message = (*env)->CallObjectMethod(env, previousException,
-				     getMessageID);
+  message = (*env)->CallObjectMethod (env, previousException, getMessageID);
 
-  newException = (*env)->NewObject(env, internalErrorClass, initException,
-				   message);
-  (*env)->CallVoidMethod(env, newException, initCauseID,
-			 previousException);
+  newException = (*env)->NewObject (env, internalErrorClass, initException,
+				    message);
+  (*env)->CallVoidMethod (env, newException, initCauseID, previousException);
 
-  (*env)->ExceptionClear(env);
-  (*env)->Throw(env, newException);
+  (*env)->ExceptionClear (env);
+  (*env)->Throw (env, newException);
 }
 
-static jfieldID getFieldReference(JNIEnv *env, jobject field, 
-				  const char *type)
+static jfieldID
+getFieldReference (JNIEnv * env, jobject field, const char *type)
 {
   jclass classClass;
   jclass fieldClass;
@@ -120,69 +119,67 @@ static jfieldID getFieldReference(JNIEnv *env, jobject field,
   jstring tname;
   int i;
 
-  fieldClass = (*env)->GetObjectClass(env, field);
+  fieldClass = (*env)->GetObjectClass (env, field);
 
-  mid = (*env)->GetMethodID(env, fieldClass, "getName", "()Ljava/lang/String;");
-  if (mid == NULL || (*env)->ExceptionOccurred(env) != NULL)
+  mid =
+    (*env)->GetMethodID (env, fieldClass, "getName", "()Ljava/lang/String;");
+  if (mid == NULL || (*env)->ExceptionOccurred (env) != NULL)
     {
-      throwInternalError(env);
+      throwInternalError (env);
       return NULL;
     }
 
-  name = (*env)->CallObjectMethod(env, field, mid);
-  field_name = (*env)->GetStringUTFChars(env, name, NULL);
- 
-  mid = (*env)->GetMethodID(env, fieldClass,
-			    "getDeclaringClass",
-			    "()Ljava/lang/Class;");
-  if (mid == NULL || (*env)->ExceptionOccurred(env) != NULL)
+  name = (*env)->CallObjectMethod (env, field, mid);
+  field_name = (*env)->GetStringUTFChars (env, name, NULL);
+
+  mid = (*env)->GetMethodID (env, fieldClass,
+			     "getDeclaringClass", "()Ljava/lang/Class;");
+  if (mid == NULL || (*env)->ExceptionOccurred (env) != NULL)
     {
-      throwInternalError(env);
+      throwInternalError (env);
       return NULL;
     }
 
-  declaringClass = (*env)->CallObjectMethod(env, field, mid);
+  declaringClass = (*env)->CallObjectMethod (env, field, mid);
 
   /* Do we need to find out the exact type descriptor of the field? */
   if (type == NULL)
     {
       char *the_type;
 
-      mid = (*env)->GetMethodID(env, fieldClass,
-				"getType",
-				"()Ljava/lang/Class;");
+      mid = (*env)->GetMethodID (env, fieldClass,
+				 "getType", "()Ljava/lang/Class;");
 
-      if (mid == NULL || (*env)->ExceptionOccurred(env) != NULL)
+      if (mid == NULL || (*env)->ExceptionOccurred (env) != NULL)
 	{
-	  throwInternalError(env);
+	  throwInternalError (env);
 	  return NULL;
 	}
 
-      typeClass = (*env)->CallObjectMethod(env, field, mid);
-      classClass = (*env)->FindClass(env, "java/lang/Class");
+      typeClass = (*env)->CallObjectMethod (env, field, mid);
+      classClass = (*env)->FindClass (env, "java/lang/Class");
 
-      mid = (*env)->GetMethodID(env, classClass,
-				"getName",
-				"()Ljava/lang/String;");
+      mid = (*env)->GetMethodID (env, classClass,
+				 "getName", "()Ljava/lang/String;");
 
-      if (mid == NULL || (*env)->ExceptionOccurred(env) != NULL)
+      if (mid == NULL || (*env)->ExceptionOccurred (env) != NULL)
 	{
-	  throwInternalError(env);
+	  throwInternalError (env);
 	  return NULL;
 	}
 
-      tname = (*env)->CallObjectMethod(env, typeClass, mid);
-      type_name = (*env)->GetStringUTFChars(env, tname, NULL);
+      tname = (*env)->CallObjectMethod (env, typeClass, mid);
+      type_name = (*env)->GetStringUTFChars (env, tname, NULL);
 
       /*
        * If it isn't an array class then the actual field type descriptor
        * starts with 'L', ends with ';' and has '/' instead of '.'.
        */
-      type_len = strlen((char *) type_name);
+      type_len = strlen ((char *) type_name);
       if (type_name[0] != '[')
-        {
+	{
 	  /* XXX - FIXME - should not use dynamic allocation in core lib. */
-	  the_type = (char *) malloc(type_len + 3);
+	  the_type = (char *) malloc (type_len + 3);
 	  the_type[0] = 'L';
 	  the_type[type_len + 1] = ';';
 	  the_type[type_len + 2] = '\0';
@@ -191,35 +188,35 @@ static jfieldID getFieldReference(JNIEnv *env, jobject field,
       else
 	{
 	  /* XXX - FIXME - should not use dynamic allocation in core lib. */
-	  the_type = (char *) malloc(type_len + 1);
+	  the_type = (char *) malloc (type_len + 1);
 	  the_type[type_len] = '\0';
 	}
 
       for (i = 0; i < type_len; i++)
 	if (type_name[i] == '.')
 	  the_type[i] = '/';
-        else
+	else
 	  the_type[i] = type_name[i];
 
       if (type_name[0] != '[')
 	the_type--;
 
-      (*env)->ReleaseStringUTFChars(env, tname, type_name);
-      fid = (*env)->GetFieldID(env, declaringClass, field_name, the_type);
-      free(the_type);
+      (*env)->ReleaseStringUTFChars (env, tname, type_name);
+      fid = (*env)->GetFieldID (env, declaringClass, field_name, the_type);
+      free (the_type);
     }
   else
     {
       type_len = -1;
-      fid = (*env)->GetFieldID(env, declaringClass, field_name, type);
+      fid = (*env)->GetFieldID (env, declaringClass, field_name, type);
     }
 
   if (fid == NULL)
     {
-      throwInternalError(env);
+      throwInternalError (env);
       return NULL;
     }
-  (*env)->ReleaseStringUTFChars(env, name, field_name);
+  (*env)->ReleaseStringUTFChars (env, name, field_name);
 
   return fid;
 }
@@ -230,17 +227,14 @@ static jfieldID getFieldReference(JNIEnv *env, jobject field,
  * Signature: (Ljava/lang/reflect/Field;Ljava/lang/Object;Z)V
  */
 JNIEXPORT void JNICALL
-Java_java_io_VMObjectStreamClass_setBooleanNative(JNIEnv * env,
-						  jclass vmosklass
-						  __attribute__ ((__unused__)),
-						  jobject field,
-						  jobject object,
-						  jboolean value )
+Java_java_io_VMObjectStreamClass_setBooleanNative (JNIEnv * env,
+						   jclass vmosklass
+						   __attribute__ ((__unused__)), jobject field, jobject object, jboolean value)
 {
   jfieldID fid = getFieldReference (env, field, "Z");
 
   if (fid != NULL)
-    (*env)->SetBooleanField(env, object, fid, value);
+    (*env)->SetBooleanField (env, object, fid, value);
 }
 
 /*
@@ -249,17 +243,16 @@ Java_java_io_VMObjectStreamClass_setBooleanNative(JNIEnv * env,
  * Signature: (Ljava/lang/reflect/Field;Ljava/lang/Object;C)V
  */
 JNIEXPORT void JNICALL
-Java_java_io_VMObjectStreamClass_setCharNative(JNIEnv * env,
-					       jclass vmosklass
-					       __attribute__ ((__unused__)),
-					       jobject field,
-					       jobject object,
-					       jchar value )
+Java_java_io_VMObjectStreamClass_setCharNative (JNIEnv * env,
+						jclass vmosklass
+						__attribute__ ((__unused__)),
+						jobject field,
+						jobject object, jchar value)
 {
   jfieldID fid = getFieldReference (env, field, "C");
 
   if (fid != NULL)
-    (*env)->SetCharField(env, object, fid, value);
+    (*env)->SetCharField (env, object, fid, value);
 }
 
 /*
@@ -268,17 +261,16 @@ Java_java_io_VMObjectStreamClass_setCharNative(JNIEnv * env,
  * Signature: (Ljava/lang/reflect/Field;Ljava/lang/Object;B)V
  */
 JNIEXPORT void JNICALL
-Java_java_io_VMObjectStreamClass_setByteNative(JNIEnv * env,
-					       jclass vmosklass
-					       __attribute__ ((__unused__)),
-					       jobject field,
-					       jobject object,
-					       jbyte value )
+Java_java_io_VMObjectStreamClass_setByteNative (JNIEnv * env,
+						jclass vmosklass
+						__attribute__ ((__unused__)),
+						jobject field,
+						jobject object, jbyte value)
 {
   jfieldID fid = getFieldReference (env, field, "B");
 
   if (fid != NULL)
-    (*env)->SetByteField(env, object, fid, value);
+    (*env)->SetByteField (env, object, fid, value);
 }
 
 
@@ -288,17 +280,16 @@ Java_java_io_VMObjectStreamClass_setByteNative(JNIEnv * env,
  * Signature: (Ljava/lang/reflect/Field;Ljava/lang/Object;S)V
  */
 JNIEXPORT void JNICALL
-Java_java_io_VMObjectStreamClass_setShortNative(JNIEnv * env,
-						jclass vmosklass
-						__attribute__ ((__unused__)),
-						jobject field,
-						jobject object,
-						jshort value )
+Java_java_io_VMObjectStreamClass_setShortNative (JNIEnv * env,
+						 jclass vmosklass
+						 __attribute__ ((__unused__)),
+						 jobject field,
+						 jobject object, jshort value)
 {
   jfieldID fid = getFieldReference (env, field, "S");
 
   if (fid != NULL)
-    (*env)->SetShortField(env, object, fid, value);
+    (*env)->SetShortField (env, object, fid, value);
 }
 
 /*
@@ -307,17 +298,16 @@ Java_java_io_VMObjectStreamClass_setShortNative(JNIEnv * env,
  * Signature: (Ljava/lang/reflect/Field;Ljava/lang/Object;I)V
  */
 JNIEXPORT void JNICALL
-Java_java_io_VMObjectStreamClass_setIntNative(JNIEnv * env,
-					      jclass vmosklass
-					      __attribute__ ((__unused__)),
-					      jobject field,
-					      jobject object,
-					      jint value )
+Java_java_io_VMObjectStreamClass_setIntNative (JNIEnv * env,
+					       jclass vmosklass
+					       __attribute__ ((__unused__)),
+					       jobject field,
+					       jobject object, jint value)
 {
   jfieldID fid = getFieldReference (env, field, "I");
 
   if (fid != NULL)
-    (*env)->SetIntField(env, object, fid, value);
+    (*env)->SetIntField (env, object, fid, value);
 }
 
 
@@ -327,17 +317,16 @@ Java_java_io_VMObjectStreamClass_setIntNative(JNIEnv * env,
  * Signature: (Ljava/lang/reflect/Field;Ljava/lang/Object;J)V
  */
 JNIEXPORT void JNICALL
-Java_java_io_VMObjectStreamClass_setLongNative(JNIEnv * env,
-					       jclass vmosklass
-					       __attribute__ ((__unused__)),
-					       jobject field,
-					       jobject object,
-					       jlong value )
+Java_java_io_VMObjectStreamClass_setLongNative (JNIEnv * env,
+						jclass vmosklass
+						__attribute__ ((__unused__)),
+						jobject field,
+						jobject object, jlong value)
 {
   jfieldID fid = getFieldReference (env, field, "J");
 
   if (fid != NULL)
-    (*env)->SetLongField(env, object, fid, value);
+    (*env)->SetLongField (env, object, fid, value);
 }
 
 
@@ -347,17 +336,16 @@ Java_java_io_VMObjectStreamClass_setLongNative(JNIEnv * env,
  * Signature: (Ljava/lang/reflect/Field;Ljava/lang/Object;F)V
  */
 JNIEXPORT void JNICALL
-Java_java_io_VMObjectStreamClass_setFloatNative(JNIEnv * env,
-						jclass vmosklass
-						__attribute__ ((__unused__)),
-						jobject field,
-						jobject object,
-						jfloat value )
+Java_java_io_VMObjectStreamClass_setFloatNative (JNIEnv * env,
+						 jclass vmosklass
+						 __attribute__ ((__unused__)),
+						 jobject field,
+						 jobject object, jfloat value)
 {
   jfieldID fid = getFieldReference (env, field, "F");
 
   if (fid != NULL)
-    (*env)->SetFloatField(env, object, fid, value);
+    (*env)->SetFloatField (env, object, fid, value);
 }
 
 /*
@@ -366,17 +354,14 @@ Java_java_io_VMObjectStreamClass_setFloatNative(JNIEnv * env,
  * Signature: (Ljava/lang/reflect/Field;Ljava/lang/Object;D)V
  */
 JNIEXPORT void JNICALL
-Java_java_io_VMObjectStreamClass_setDoubleNative(JNIEnv * env,
-						 jclass vmosklass
-						 __attribute__ ((__unused__)),
-						 jobject field,
-						 jobject object,
-						 jdouble value )
+Java_java_io_VMObjectStreamClass_setDoubleNative (JNIEnv * env,
+						  jclass vmosklass
+						  __attribute__ ((__unused__)), jobject field, jobject object, jdouble value)
 {
   jfieldID fid = getFieldReference (env, field, "D");
 
   if (fid != NULL)
-    (*env)->SetDoubleField(env, object, fid, value);
+    (*env)->SetDoubleField (env, object, fid, value);
 }
 
 /*
@@ -385,15 +370,12 @@ Java_java_io_VMObjectStreamClass_setDoubleNative(JNIEnv * env,
  * Signature: (Ljava/lang/reflect/Field;Ljava/lang/Object;Ljava/lang/Object;)V
  */
 JNIEXPORT void JNICALL
-Java_java_io_VMObjectStreamClass_setObjectNative(JNIEnv * env,
-						 jclass vmosklass
-						 __attribute__ ((__unused__)),
-						 jobject field,
-						 jobject object,
-						 jobject value )
+Java_java_io_VMObjectStreamClass_setObjectNative (JNIEnv * env,
+						  jclass vmosklass
+						  __attribute__ ((__unused__)), jobject field, jobject object, jobject value)
 {
   jfieldID fid = getFieldReference (env, field, NULL);
 
   if (fid != NULL)
-    (*env)->SetObjectField(env, object, fid, value);
+    (*env)->SetObjectField (env, object, fid, value);
 }
