@@ -52,8 +52,8 @@ exception statement from your version. */
 #include "target_native_misc.h"
 
 /* Internal functions */
-static char *copy_string(JNIEnv *env, jobject string);
-static char *copy_elem(JNIEnv *env, jobject stringArray, jint i);
+static char *copy_string (JNIEnv * env, jobject string);
+static char *copy_elem (JNIEnv * env, jobject stringArray, jint i);
 
 /* Some O/S's don't declare 'environ' */
 #if HAVE_CRT_EXTERNS_H
@@ -70,7 +70,7 @@ extern char **environ;
  * Internal helper function to copy a String in UTF-8 format.
  */
 static char *
-copy_string(JNIEnv *env, jobject string)
+copy_string (JNIEnv * env, jobject string)
 {
   char errbuf[64];
   const char *utf;
@@ -80,33 +80,33 @@ copy_string(JNIEnv *env, jobject string)
   /* Check for null */
   if (string == NULL)
     {
-      clazz = (*env)->FindClass(env, "java/lang/NullPointerException");
-      if ((*env)->ExceptionOccurred(env))
+      clazz = (*env)->FindClass (env, "java/lang/NullPointerException");
+      if ((*env)->ExceptionOccurred (env))
 	return NULL;
-      (*env)->ThrowNew(env, clazz, NULL);
-      (*env)->DeleteLocalRef(env, clazz);
+      (*env)->ThrowNew (env, clazz, NULL);
+      (*env)->DeleteLocalRef (env, clazz);
       return NULL;
     }
 
   /* Extract UTF-8 */
-  utf = (*env)->GetStringUTFChars(env, string, NULL);
-  if ((*env)->ExceptionOccurred(env))
+  utf = (*env)->GetStringUTFChars (env, string, NULL);
+  if ((*env)->ExceptionOccurred (env))
     return NULL;
 
   /* Copy it */
-  if ((copy = strdup(utf)) == NULL)
+  if ((copy = strdup (utf)) == NULL)
     {
-      TARGET_NATIVE_MISC_FORMAT_STRING1(errbuf, sizeof(errbuf),
-	"strdup: %s", strerror(errno));
-      clazz = (*env)->FindClass(env, "java/lang/InternalError");
-      if ((*env)->ExceptionOccurred(env))
+      TARGET_NATIVE_MISC_FORMAT_STRING1 (errbuf, sizeof (errbuf),
+					 "strdup: %s", strerror (errno));
+      clazz = (*env)->FindClass (env, "java/lang/InternalError");
+      if ((*env)->ExceptionOccurred (env))
 	return NULL;
-      (*env)->ThrowNew(env, clazz, errbuf);
-      (*env)->DeleteLocalRef(env, clazz);
+      (*env)->ThrowNew (env, clazz, errbuf);
+      (*env)->DeleteLocalRef (env, clazz);
     }
 
   /* Done */
-  (*env)->ReleaseStringUTFChars(env, string, utf);
+  (*env)->ReleaseStringUTFChars (env, string, utf);
   return copy;
 }
 
@@ -114,17 +114,17 @@ copy_string(JNIEnv *env, jobject string)
  * Internal helper function to copy a String[] element in UTF-8 format.
  */
 static char *
-copy_elem(JNIEnv *env, jobject stringArray, jint i)
+copy_elem (JNIEnv * env, jobject stringArray, jint i)
 {
   jobject elem;
   char *rtn;
 
-  elem = (*env)->GetObjectArrayElement(env, stringArray, i);
-  if ((*env)->ExceptionOccurred(env))
+  elem = (*env)->GetObjectArrayElement (env, stringArray, i);
+  if ((*env)->ExceptionOccurred (env))
     return NULL;
-  if ((rtn = copy_string(env, elem)) == NULL)
+  if ((rtn = copy_string (env, elem)) == NULL)
     return NULL;
-  (*env)->DeleteLocalRef(env, elem);
+  (*env)->DeleteLocalRef (env, elem);
   return rtn;
 }
 
@@ -133,10 +133,11 @@ copy_elem(JNIEnv *env, jobject stringArray, jint i)
  *	throws java/io/IOException
  */
 JNIEXPORT void JNICALL
-Java_java_lang_VMProcess_nativeSpawn(JNIEnv *env, jobject this,
-	jobjectArray cmdArray, jobjectArray envArray, jobject dirFile)
+Java_java_lang_VMProcess_nativeSpawn (JNIEnv * env, jobject this,
+				      jobjectArray cmdArray,
+				      jobjectArray envArray, jobject dirFile)
 {
-  int fds[3][2] = { { -1, -1 }, { -1, -1 }, { -1, -1 } };
+  int fds[3][2] = { {-1, -1}, {-1, -1}, {-1, -1} };
   jobject streams[3] = { NULL, NULL, NULL };
   jobject dirString = NULL;
   char **newEnviron = NULL;
@@ -158,17 +159,17 @@ Java_java_lang_VMProcess_nativeSpawn(JNIEnv *env, jobject this,
   /* Invoke dirFile.getPath() */
   if (dirFile != NULL)
     {
-      clazz = (*env)->FindClass(env, "java/io/File");
-      if ((*env)->ExceptionOccurred(env))
+      clazz = (*env)->FindClass (env, "java/io/File");
+      if ((*env)->ExceptionOccurred (env))
 	return;
-      method = (*env)->GetMethodID(env,
-	clazz, "getPath", "()Ljava/lang/String;");
-      if ((*env)->ExceptionOccurred(env))
+      method = (*env)->GetMethodID (env,
+				    clazz, "getPath", "()Ljava/lang/String;");
+      if ((*env)->ExceptionOccurred (env))
 	return;
-      dirString = (*env)->CallObjectMethod(env, dirFile, method);
-      if ((*env)->ExceptionOccurred(env))
+      dirString = (*env)->CallObjectMethod (env, dirFile, method);
+      if ((*env)->ExceptionOccurred (env))
 	return;
-      (*env)->DeleteLocalRef(env, clazz);
+      (*env)->DeleteLocalRef (env, clazz);
     }
 
   /*
@@ -176,38 +177,42 @@ Java_java_lang_VMProcess_nativeSpawn(JNIEnv *env, jobject this,
    * handle the command parameters, the new environment, and the new
    * directory into a single array for simplicity of (de)allocation.
    */
-  cmdArrayLen = (*env)->GetArrayLength(env, cmdArray);
+  cmdArrayLen = (*env)->GetArrayLength (env, cmdArray);
+  if (cmdArrayLen == 0)
+    goto null_pointer_exception;
   if (envArray != NULL)
-    envArrayLen = (*env)->GetArrayLength(env, envArray);
-  if ((strings = malloc(((cmdArrayLen + 1)
-      + (envArray != NULL ? envArrayLen + 1 : 0)
-      + (dirString != NULL ? 1 : 0)) * sizeof(*strings))) == NULL)
+    envArrayLen = (*env)->GetArrayLength (env, envArray);
+  if ((strings = malloc (((cmdArrayLen + 1)
+			  + (envArray != NULL ? envArrayLen + 1 : 0)
+			  + (dirString !=
+			     NULL ? 1 : 0)) * sizeof (*strings))) == NULL)
     {
-      TARGET_NATIVE_MISC_FORMAT_STRING1(errbuf,
-	sizeof(errbuf), "malloc: %s", strerror(errno));
+      TARGET_NATIVE_MISC_FORMAT_STRING1 (errbuf,
+					 sizeof (errbuf), "malloc: %s",
+					 strerror (errno));
       goto out_of_memory;
     }
 
   /* Extract C strings from the various String parameters */
   for (i = 0; i < cmdArrayLen; i++)
     {
-      if ((strings[num_strings++] = copy_elem(env, cmdArray, i)) == NULL)
+      if ((strings[num_strings++] = copy_elem (env, cmdArray, i)) == NULL)
 	goto done;
     }
-  strings[num_strings++] = NULL;		/* terminate array with NULL */
+  strings[num_strings++] = NULL;	/* terminate array with NULL */
   if (envArray != NULL)
     {
       newEnviron = strings + num_strings;
       for (i = 0; i < envArrayLen; i++)
 	{
-	  if ((strings[num_strings++] = copy_elem(env, envArray, i)) == NULL)
+	  if ((strings[num_strings++] = copy_elem (env, envArray, i)) == NULL)
 	    goto done;
 	}
-      strings[num_strings++] = NULL;		/* terminate array with NULL */
+      strings[num_strings++] = NULL;	/* terminate array with NULL */
     }
   if (dirString != NULL)
     {
-      if ((dir = copy_string(env, dirString)) == NULL)
+      if ((dir = copy_string (env, dirString)) == NULL)
 	goto done;
       strings[num_strings++] = dir;
     }
@@ -215,24 +220,26 @@ Java_java_lang_VMProcess_nativeSpawn(JNIEnv *env, jobject this,
   /* Create inter-process pipes */
   for (i = 0; i < 3; i++)
     {
-      if (pipe(fds[i]) == -1)
+      if (pipe (fds[i]) == -1)
 	{
-	  TARGET_NATIVE_MISC_FORMAT_STRING1(errbuf,
-	    sizeof(errbuf), "pipe: %s", strerror(errno));
+	  TARGET_NATIVE_MISC_FORMAT_STRING1 (errbuf,
+					     sizeof (errbuf), "pipe: %s",
+					     strerror (errno));
 	  goto system_error;
 	}
     }
 
   /* Set close-on-exec flag for parent's ends of pipes */
-  (void)fcntl(fds[0][1], F_SETFD, 1);
-  (void)fcntl(fds[1][0], F_SETFD, 1);
-  (void)fcntl(fds[2][0], F_SETFD, 1);
+  (void) fcntl (fds[0][1], F_SETFD, 1);
+  (void) fcntl (fds[1][0], F_SETFD, 1);
+  (void) fcntl (fds[2][0], F_SETFD, 1);
 
   /* Fork into parent and child processes */
-  if ((pid = fork()) == (pid_t)-1)
+  if ((pid = fork ()) == (pid_t) - 1)
     {
-      TARGET_NATIVE_MISC_FORMAT_STRING1(errbuf,
-	sizeof(errbuf), "fork: %s", strerror(errno));
+      TARGET_NATIVE_MISC_FORMAT_STRING1 (errbuf,
+					 sizeof (errbuf), "fork: %s",
+					 strerror (errno));
       goto system_error;
     }
 
@@ -244,42 +251,42 @@ Java_java_lang_VMProcess_nativeSpawn(JNIEnv *env, jobject this,
       /* Move file descriptors to standard locations */
       if (fds[0][0] != 0)
 	{
-	  if (dup2(fds[0][0], 0) == -1)
+	  if (dup2 (fds[0][0], 0) == -1)
 	    {
-	      fprintf(stderr, "dup2: %s", strerror(errno));
-	      exit(127);
+	      fprintf (stderr, "dup2: %s", strerror (errno));
+	      exit (127);
 	    }
-	  close(fds[0][0]);
+	  close (fds[0][0]);
 	}
       if (fds[1][1] != 1)
 	{
-	  if (dup2(fds[1][1], 1) == -1)
+	  if (dup2 (fds[1][1], 1) == -1)
 	    {
-	      fprintf(stderr, "dup2: %s", strerror(errno));
-	      exit(127);
+	      fprintf (stderr, "dup2: %s", strerror (errno));
+	      exit (127);
 	    }
-	  close(fds[1][1]);
+	  close (fds[1][1]);
 	}
       if (fds[2][1] != 2)
 	{
-	  if (dup2(fds[2][1], 2) == -1)
+	  if (dup2 (fds[2][1], 2) == -1)
 	    {
-	      fprintf(stderr, "dup2: %s", strerror(errno));
-	      exit(127);
+	      fprintf (stderr, "dup2: %s", strerror (errno));
+	      exit (127);
 	    }
-	  close(fds[2][1]);
+	  close (fds[2][1]);
 	}
 
       /* Change into destination directory */
-      if (dir != NULL && chdir(dir) == -1)
+      if (dir != NULL && chdir (dir) == -1)
 	{
-	  fprintf(stderr, "%s: %s", dir, strerror(errno));
-	  exit(127);
+	  fprintf (stderr, "%s: %s", dir, strerror (errno));
+	  exit (127);
 	}
 
       /* Make argv[0] last component of executable pathname */
       /* XXX should use "file.separator" property here XXX */
-      for (i = strlen(path); i > 0 && path[i - 1] != '/'; i--);
+      for (i = strlen (path); i > 0 && path[i - 1] != '/'; i--);
       strings[0] = path + i;
 
       /* Set new environment */
@@ -287,19 +294,19 @@ Java_java_lang_VMProcess_nativeSpawn(JNIEnv *env, jobject this,
 	environ = newEnviron;
 
       /* Execute new program (this will close the parent end of the pipes) */
-      execvp(path, strings);
+      execvp (path, strings);
 
       /* Failed */
-      fprintf(stderr, "%s: %s", path, strerror(errno));
-      exit(127);
+      fprintf (stderr, "%s: %s", path, strerror (errno));
+      exit (127);
     }
 
   /* Create Input/OutputStream objects around parent file descriptors */
-  clazz = (*env)->FindClass(env, "gnu/java/nio/channels/FileChannelImpl");
-  if ((*env)->ExceptionOccurred(env))
+  clazz = (*env)->FindClass (env, "gnu/java/nio/channels/FileChannelImpl");
+  if ((*env)->ExceptionOccurred (env))
     goto done;
-  method = (*env)->GetMethodID(env, clazz, "<init>", "(II)V");
-  if ((*env)->ExceptionOccurred(env))
+  method = (*env)->GetMethodID (env, clazz, "<init>", "(II)V");
+  if ((*env)->ExceptionOccurred (env))
     goto done;
   for (i = 0; i < 3; i++)
     {
@@ -309,41 +316,42 @@ Java_java_lang_VMProcess_nativeSpawn(JNIEnv *env, jobject this,
       jclass sclazz;
       jmethodID smethod;
 
-      jobject channel = (*env)->NewObject(env, clazz, method, fd, mode);
-      if ((*env)->ExceptionOccurred(env))
+      jobject channel = (*env)->NewObject (env, clazz, method, fd, mode);
+      if ((*env)->ExceptionOccurred (env))
 	goto done;
 
       if (mode == 2)
-	sclazz = (*env)->FindClass(env, "java/io/FileOutputStream");
+	sclazz = (*env)->FindClass (env, "java/io/FileOutputStream");
       else
-	sclazz = (*env)->FindClass(env, "java/io/FileInputStream");
-      if ((*env)->ExceptionOccurred(env))
+	sclazz = (*env)->FindClass (env, "java/io/FileInputStream");
+      if ((*env)->ExceptionOccurred (env))
 	goto done;
 
-      smethod = (*env)->GetMethodID(env, sclazz, "<init>",
-			"(Lgnu/java/nio/channels/FileChannelImpl;)V");
-      if ((*env)->ExceptionOccurred(env))
+      smethod = (*env)->GetMethodID (env, sclazz, "<init>",
+				     "(Lgnu/java/nio/channels/FileChannelImpl;)V");
+      if ((*env)->ExceptionOccurred (env))
 	goto done;
 
-      streams[i] = (*env)->NewObject(env, sclazz, smethod, channel);
-      if ((*env)->ExceptionOccurred(env))
+      streams[i] = (*env)->NewObject (env, sclazz, smethod, channel);
+      if ((*env)->ExceptionOccurred (env))
 	goto done;
 
-      (*env)->DeleteLocalRef(env, sclazz);
+      (*env)->DeleteLocalRef (env, sclazz);
     }
-  (*env)->DeleteLocalRef(env, clazz);
+  (*env)->DeleteLocalRef (env, clazz);
 
   /* Invoke VMProcess.setProcessInfo() to update VMProcess object */
-  method = (*env)->GetMethodID(env,
-    (*env)->GetObjectClass(env, this), "setProcessInfo",
-    "(Ljava/io/OutputStream;Ljava/io/InputStream;Ljava/io/InputStream;J)V");
-  if ((*env)->ExceptionOccurred(env))
+  method = (*env)->GetMethodID (env,
+				(*env)->GetObjectClass (env, this),
+				"setProcessInfo",
+				"(Ljava/io/OutputStream;Ljava/io/InputStream;Ljava/io/InputStream;J)V");
+  if ((*env)->ExceptionOccurred (env))
     goto done;
-  (*env)->CallVoidMethod(env, this, method,
-    streams[0], streams[1], streams[2], (jlong)pid);
-  if ((*env)->ExceptionOccurred(env))
+  (*env)->CallVoidMethod (env, this, method,
+			  streams[0], streams[1], streams[2], (jlong) pid);
+  if ((*env)->ExceptionOccurred (env))
     goto done;
-  (*env)->DeleteLocalRef(env, clazz);
+  (*env)->DeleteLocalRef (env, clazz);
 
 done:
   /*
@@ -357,7 +365,7 @@ done:
       const int fd = fds[i][i != 0];
 
       if (fd != -1)
-	close(fd);
+	close (fd);
     }
 
   /*
@@ -371,39 +379,39 @@ done:
       const int fd = fds[i][i == 0];
 
       if (fd != -1 && streams[i] == NULL)
-	close(fd);
+	close (fd);
     }
 
   /* Free C strings */
   while (num_strings > 0)
-    free(strings[--num_strings]);
-  free(strings);
+    free (strings[--num_strings]);
+  free (strings);
 
   /* Done */
   return;
 
 null_pointer_exception:
-  clazz = (*env)->FindClass(env, "java/lang/NullPointerException");
-  if ((*env)->ExceptionOccurred(env))
+  clazz = (*env)->FindClass (env, "java/lang/NullPointerException");
+  if ((*env)->ExceptionOccurred (env))
     goto done;
-  (*env)->ThrowNew(env, clazz, NULL);
-  (*env)->DeleteLocalRef(env, clazz);
+  (*env)->ThrowNew (env, clazz, NULL);
+  (*env)->DeleteLocalRef (env, clazz);
   goto done;
 
 out_of_memory:
-  clazz = (*env)->FindClass(env, "java/lang/InternalError");
-  if ((*env)->ExceptionOccurred(env))
+  clazz = (*env)->FindClass (env, "java/lang/InternalError");
+  if ((*env)->ExceptionOccurred (env))
     goto done;
-  (*env)->ThrowNew(env, clazz, errbuf);
-  (*env)->DeleteLocalRef(env, clazz);
+  (*env)->ThrowNew (env, clazz, errbuf);
+  (*env)->DeleteLocalRef (env, clazz);
   goto done;
 
 system_error:
-  clazz = (*env)->FindClass(env, "java/io/IOException");
-  if ((*env)->ExceptionOccurred(env))
+  clazz = (*env)->FindClass (env, "java/io/IOException");
+  if ((*env)->ExceptionOccurred (env))
     goto done;
-  (*env)->ThrowNew(env, clazz, errbuf);
-  (*env)->DeleteLocalRef(env, clazz);
+  (*env)->ThrowNew (env, clazz, errbuf);
+  (*env)->DeleteLocalRef (env, clazz);
   goto done;
 }
 
@@ -411,7 +419,7 @@ system_error:
  * private static final native boolean nativeReap()
  */
 JNIEXPORT jboolean JNICALL
-Java_java_lang_VMProcess_nativeReap(JNIEnv *env, jclass clazz)
+Java_java_lang_VMProcess_nativeReap (JNIEnv * env, jclass clazz)
 {
   char ebuf[64];
   jfieldID field;
@@ -419,44 +427,45 @@ Java_java_lang_VMProcess_nativeReap(JNIEnv *env, jclass clazz)
   pid_t pid;
 
   /* Try to reap a child process, but don't block */
-  if ((pid = waitpid((pid_t)-1, &status, WNOHANG)) == 0)
+  if ((pid = waitpid ((pid_t) - 1, &status, WNOHANG)) == 0)
     return JNI_FALSE;
 
   /* Check result from waitpid() */
-  if (pid == (pid_t)-1)
+  if (pid == (pid_t) - 1)
     {
       if (errno == ECHILD || errno == EINTR)
 	return JNI_FALSE;
-      TARGET_NATIVE_MISC_FORMAT_STRING2(ebuf,
-	sizeof(ebuf), "waitpid(%ld): %s", (long)pid, strerror(errno));
-      clazz = (*env)->FindClass(env, "java/lang/InternalError");
-      if ((*env)->ExceptionOccurred(env))
+      TARGET_NATIVE_MISC_FORMAT_STRING2 (ebuf,
+					 sizeof (ebuf), "waitpid(%ld): %s",
+					 (long) pid, strerror (errno));
+      clazz = (*env)->FindClass (env, "java/lang/InternalError");
+      if ((*env)->ExceptionOccurred (env))
 	return JNI_FALSE;
-      (*env)->ThrowNew(env, clazz, ebuf);
-      (*env)->DeleteLocalRef(env, clazz);
+      (*env)->ThrowNew (env, clazz, ebuf);
+      (*env)->DeleteLocalRef (env, clazz);
       return JNI_FALSE;
     }
 
   /* Get exit code; for signal termination return negative signal value XXX */
-  if (WIFEXITED(status))
-    status = (jint)(jbyte)WEXITSTATUS(status);
-  else if (WIFSIGNALED(status))
-    status = -(jint)WTERMSIG(status);
+  if (WIFEXITED (status))
+    status = (jint) (jbyte) WEXITSTATUS (status);
+  else if (WIFSIGNALED (status))
+    status = -(jint) WTERMSIG (status);
   else
-    return JNI_FALSE;			/* process merely stopped; ignore */
+    return JNI_FALSE;		/* process merely stopped; ignore */
 
   /* Return process pid and exit status */
-  field = (*env)->GetStaticFieldID(env, clazz, "reapedPid", "J");
-  if ((*env)->ExceptionOccurred(env))
+  field = (*env)->GetStaticFieldID (env, clazz, "reapedPid", "J");
+  if ((*env)->ExceptionOccurred (env))
     return JNI_FALSE;
-  (*env)->SetStaticLongField(env, clazz, field, (jlong)pid);
-  if ((*env)->ExceptionOccurred(env))
+  (*env)->SetStaticLongField (env, clazz, field, (jlong) pid);
+  if ((*env)->ExceptionOccurred (env))
     return JNI_FALSE;
-  field = (*env)->GetStaticFieldID(env, clazz, "reapedExitValue", "I");
-  if ((*env)->ExceptionOccurred(env))
+  field = (*env)->GetStaticFieldID (env, clazz, "reapedExitValue", "I");
+  if ((*env)->ExceptionOccurred (env))
     return JNI_FALSE;
-  (*env)->SetStaticIntField(env, clazz, field, status);
-  if ((*env)->ExceptionOccurred(env))
+  (*env)->SetStaticIntField (env, clazz, field, status);
+  if ((*env)->ExceptionOccurred (env))
     return JNI_FALSE;
 
   /* Done */
@@ -467,19 +476,19 @@ Java_java_lang_VMProcess_nativeReap(JNIEnv *env, jclass clazz)
  * private static final native void nativeKill(long)
  */
 JNIEXPORT void JNICALL
-Java_java_lang_VMProcess_nativeKill(JNIEnv *env, jclass clazz, jlong pid)
+Java_java_lang_VMProcess_nativeKill (JNIEnv * env, jclass clazz, jlong pid)
 {
   char ebuf[64];
 
-  if (kill((pid_t)pid, SIGKILL) == -1)
+  if (kill ((pid_t) pid, SIGKILL) == -1)
     {
-      TARGET_NATIVE_MISC_FORMAT_STRING2(ebuf,
-	sizeof(ebuf), "kill(%ld): %s", (long)pid, strerror(errno));
-      clazz = (*env)->FindClass(env, "java/lang/InternalError");
-      if ((*env)->ExceptionOccurred(env))
+      TARGET_NATIVE_MISC_FORMAT_STRING2 (ebuf,
+					 sizeof (ebuf), "kill(%ld): %s",
+					 (long) pid, strerror (errno));
+      clazz = (*env)->FindClass (env, "java/lang/InternalError");
+      if ((*env)->ExceptionOccurred (env))
 	return;
-      (*env)->ThrowNew(env, clazz, ebuf);
-      (*env)->DeleteLocalRef(env, clazz);
+      (*env)->ThrowNew (env, clazz, ebuf);
+      (*env)->DeleteLocalRef (env, clazz);
     }
 }
-
