@@ -46,7 +46,7 @@ exception statement from your version. */
 
 #include "target_native.h"
 #ifndef WITHOUT_FILESYSTEM
-  #include "target_native_file.h"
+#include "target_native_file.h"
 #endif
 #include "target_native_math_int.h"
 
@@ -91,7 +91,7 @@ exception statement from your version. */
 static jfieldID native_fd_fieldID;
 
 static jint
-get_native_fd (JNIEnv *env, jobject obj)
+get_native_fd (JNIEnv * env, jobject obj)
 {
   return (*env)->GetIntField (env, obj, native_fd_fieldID);
 }
@@ -101,7 +101,7 @@ get_native_fd (JNIEnv *env, jobject obj)
  * static initialization.
  */
 JNIEXPORT void JNICALL
-Java_gnu_java_nio_channels_FileChannelImpl_init (JNIEnv *env, jclass clazz)
+Java_gnu_java_nio_channels_FileChannelImpl_init (JNIEnv * env, jclass clazz)
 {
   jclass clazz_fc;
   jfieldID field;
@@ -112,21 +112,21 @@ Java_gnu_java_nio_channels_FileChannelImpl_init (JNIEnv *env, jclass clazz)
   clazz_fc = (*env)->FindClass (env, "gnu/java/nio/channels/FileChannelImpl");
   if (!clazz_fc)
     {
-      JCL_ThrowException(env, IO_EXCEPTION, "Internal error");
+      JCL_ThrowException (env, IO_EXCEPTION, "Internal error");
       return;
     }
 
   field = (*env)->GetFieldID (env, clazz_fc, "fd", "I");
   if (!field)
     {
-      JCL_ThrowException(env, IO_EXCEPTION, "Internal error");		
+      JCL_ThrowException (env, IO_EXCEPTION, "Internal error");
       return;
     }
 
   native_fd_fieldID = field;
 
   constructor = (*env)->GetMethodID (env, clazz, "<init>", "(II)V");
-  if (! constructor)
+  if (!constructor)
     return;
 
 #define INIT_FIELD(FIELDNAME, FDVALUE, MODE)				\
@@ -152,46 +152,51 @@ Java_gnu_java_nio_channels_FileChannelImpl_init (JNIEnv *env, jclass clazz)
  * Open the specified file and return a native file descriptor
  */
 JNIEXPORT jint JNICALL
-Java_gnu_java_nio_channels_FileChannelImpl_open (JNIEnv *env,
+Java_gnu_java_nio_channels_FileChannelImpl_open (JNIEnv * env,
 						 jobject obj
 						 __attribute__ ((__unused__)),
 						 jstring name, jint mode)
 {
   const char *filename;
-  int        flags;
-  int        permissions;
-  int        native_fd;
-  int        result;
+  int flags;
+  int permissions;
+  int native_fd;
+  int result;
 
-  filename = JCL_jstring_to_cstring(env, name);
+  filename = JCL_jstring_to_cstring (env, name);
   if (filename == NULL)
-    return(-1); /* Exception will already have been thrown */
+    return (-1);		/* Exception will already have been thrown */
 
   /* get file/permission flags for open() */
-  if ((mode & FILECHANNELIMPL_FILEOPEN_FLAG_READ) && (mode & FILECHANNELIMPL_FILEOPEN_FLAG_WRITE))
+  if ((mode & FILECHANNELIMPL_FILEOPEN_FLAG_READ)
+      && (mode & FILECHANNELIMPL_FILEOPEN_FLAG_WRITE))
     {
       /* read/write */
-      flags       = TARGET_NATIVE_FILE_FILEFLAG_CREATE | TARGET_NATIVE_FILE_FILEFLAG_READWRITE;
+      flags =
+	TARGET_NATIVE_FILE_FILEFLAG_CREATE |
+	TARGET_NATIVE_FILE_FILEFLAG_READWRITE;
       permissions = TARGET_NATIVE_FILE_FILEPERMISSION_NORMAL;
     }
   else if ((mode & FILECHANNELIMPL_FILEOPEN_FLAG_READ))
     {
       /* read */
-      flags       = TARGET_NATIVE_FILE_FILEFLAG_READ;
+      flags = TARGET_NATIVE_FILE_FILEFLAG_READ;
       permissions = TARGET_NATIVE_FILE_FILEPERMISSION_NORMAL;
     }
   else
     {
       /* write */
-      flags       = TARGET_NATIVE_FILE_FILEFLAG_CREATE | TARGET_NATIVE_FILE_FILEFLAG_WRITE;
+      flags =
+	TARGET_NATIVE_FILE_FILEFLAG_CREATE |
+	TARGET_NATIVE_FILE_FILEFLAG_WRITE;
       if ((mode & FILECHANNELIMPL_FILEOPEN_FLAG_APPEND))
-        {
-           flags |= TARGET_NATIVE_FILE_FILEFLAG_APPEND;
-        }
+	{
+	  flags |= TARGET_NATIVE_FILE_FILEFLAG_APPEND;
+	}
       else
-        {
-           flags |= TARGET_NATIVE_FILE_FILEFLAG_TRUNCATE;
-        }
+	{
+	  flags |= TARGET_NATIVE_FILE_FILEFLAG_TRUNCATE;
+	}
       permissions = TARGET_NATIVE_FILE_FILEPERMISSION_NORMAL;
     }
 
@@ -208,15 +213,15 @@ Java_gnu_java_nio_channels_FileChannelImpl_open (JNIEnv *env,
   flags |= TARGET_NATIVE_FILE_FILEFLAG_BINARY;
 #endif
 
-  TARGET_NATIVE_FILE_OPEN(filename,native_fd,flags,permissions,result);
-  JCL_free_cstring(env, name, filename);
+  TARGET_NATIVE_FILE_OPEN (filename, native_fd, flags, permissions, result);
+  JCL_free_cstring (env, name, filename);
 
   if (result != TARGET_NATIVE_OK)
     {
       /* We can only throw FileNotFoundException.  */
-      JCL_ThrowException(env,
-                         "java/io/FileNotFoundException",
-                         TARGET_NATIVE_LAST_ERROR_STRING());
+      JCL_ThrowException (env,
+			  "java/io/FileNotFoundException",
+			  TARGET_NATIVE_LAST_ERROR_STRING ());
       return TARGET_NATIVE_MATH_INT_INT64_CONST_MINUS_1;
     }
 
@@ -228,18 +233,19 @@ Java_gnu_java_nio_channels_FileChannelImpl_open (JNIEnv *env,
  * Exception on error
  */
 JNIEXPORT void JNICALL
-Java_gnu_java_nio_channels_FileChannelImpl_implCloseChannel (JNIEnv *env, jobject obj)
+Java_gnu_java_nio_channels_FileChannelImpl_implCloseChannel (JNIEnv * env,
+							     jobject obj)
 {
   int native_fd;
   int result;
 
-  native_fd = get_native_fd(env, obj);
+  native_fd = get_native_fd (env, obj);
 
-  TARGET_NATIVE_FILE_CLOSE(native_fd,result);
+  TARGET_NATIVE_FILE_CLOSE (native_fd, result);
   if (result != TARGET_NATIVE_OK)
     {
-      JCL_ThrowException(env, IO_EXCEPTION,
-                         TARGET_NATIVE_LAST_ERROR_STRING());
+      JCL_ThrowException (env, IO_EXCEPTION,
+			  TARGET_NATIVE_LAST_ERROR_STRING ());
     }
 }
 
@@ -248,40 +254,41 @@ Java_gnu_java_nio_channels_FileChannelImpl_implCloseChannel (JNIEnv *env, jobjec
  * Exception on error
  */
 JNIEXPORT jint JNICALL
-Java_gnu_java_nio_channels_FileChannelImpl_available (JNIEnv *env, jobject obj)
+Java_gnu_java_nio_channels_FileChannelImpl_available (JNIEnv * env,
+						      jobject obj)
 {
-  int   native_fd;
+  int native_fd;
   jlong bytes_available;
-  int   result;
+  int result;
 
-  native_fd = get_native_fd(env, obj);
+  native_fd = get_native_fd (env, obj);
 
-  TARGET_NATIVE_FILE_AVAILABLE(native_fd,bytes_available,result);
+  TARGET_NATIVE_FILE_AVAILABLE (native_fd, bytes_available, result);
   if (result != TARGET_NATIVE_OK)
     {
-      JCL_ThrowException(env, IO_EXCEPTION,
-                         TARGET_NATIVE_LAST_ERROR_STRING());
+      JCL_ThrowException (env, IO_EXCEPTION,
+			  TARGET_NATIVE_LAST_ERROR_STRING ());
       return 0;
     }
 
   /* FIXME NYI ??? why only jint and not jlong? */
-  return TARGET_NATIVE_MATH_INT_INT64_TO_INT32(bytes_available);
+  return TARGET_NATIVE_MATH_INT_INT64_TO_INT32 (bytes_available);
 }
 
 JNIEXPORT jlong JNICALL
-Java_gnu_java_nio_channels_FileChannelImpl_size (JNIEnv *env, jobject obj)
+Java_gnu_java_nio_channels_FileChannelImpl_size (JNIEnv * env, jobject obj)
 {
-  int   native_fd;
+  int native_fd;
   jlong file_size;
-  int   result;
+  int result;
 
-  native_fd = get_native_fd(env, obj);
+  native_fd = get_native_fd (env, obj);
 
-  TARGET_NATIVE_FILE_SIZE(native_fd, file_size, result);
+  TARGET_NATIVE_FILE_SIZE (native_fd, file_size, result);
   if (result != TARGET_NATIVE_OK)
     {
-      JCL_ThrowException(env, IO_EXCEPTION,
-			 TARGET_NATIVE_LAST_ERROR_STRING());
+      JCL_ThrowException (env, IO_EXCEPTION,
+			  TARGET_NATIVE_LAST_ERROR_STRING ());
       return TARGET_NATIVE_MATH_INT_INT64_CONST_MINUS_1;
     }
 
@@ -293,19 +300,20 @@ Java_gnu_java_nio_channels_FileChannelImpl_size (JNIEnv *env, jobject obj)
  * Exception on error
  */
 JNIEXPORT jlong JNICALL
-Java_gnu_java_nio_channels_FileChannelImpl_implPosition (JNIEnv *env, jobject obj)
+Java_gnu_java_nio_channels_FileChannelImpl_implPosition (JNIEnv * env,
+							 jobject obj)
 {
-  int   native_fd;
+  int native_fd;
   jlong current_offset;
-  int   result;
+  int result;
 
-  native_fd = get_native_fd(env, obj);
+  native_fd = get_native_fd (env, obj);
 
-  TARGET_NATIVE_FILE_TELL(native_fd, current_offset, result);
+  TARGET_NATIVE_FILE_TELL (native_fd, current_offset, result);
   if (result != TARGET_NATIVE_OK)
     {
-      JCL_ThrowException(env, IO_EXCEPTION,
-                         TARGET_NATIVE_LAST_ERROR_STRING());
+      JCL_ThrowException (env, IO_EXCEPTION,
+			  TARGET_NATIVE_LAST_ERROR_STRING ());
       return TARGET_NATIVE_MATH_INT_INT64_CONST_MINUS_1;
     }
 
@@ -317,13 +325,14 @@ Java_gnu_java_nio_channels_FileChannelImpl_implPosition (JNIEnv *env, jobject ob
  * Exception on error
  */
 JNIEXPORT void JNICALL
-Java_gnu_java_nio_channels_FileChannelImpl_seek (JNIEnv *env, jobject obj, jlong offset)
+Java_gnu_java_nio_channels_FileChannelImpl_seek (JNIEnv * env, jobject obj,
+						 jlong offset)
 {
-  int   native_fd;
+  int native_fd;
   jlong new_offset;
-  int   result;
+  int result;
 
-  native_fd = get_native_fd(env, obj);
+  native_fd = get_native_fd (env, obj);
 
 #if 0
   /* Should there be such an exception? All native layer macros should
@@ -334,25 +343,25 @@ Java_gnu_java_nio_channels_FileChannelImpl_seek (JNIEnv *env, jobject obj, jlong
      to handle 64bit-values the system is limited to 32bit at all, thus
      the application can not do a seek() or something else beyond the
      32bit limit. It this true?
-  */
+   */
 
   /* FIXME: What do we do if offset > the max value of off_t on this 32bit
    * system?  How do we detect that and what do we do? */
-  if (CONVERT_OFF_T_TO_JLONG(native_offset) != offset)
+  if (CONVERT_OFF_T_TO_JLONG (native_offset) != offset)
     {
-      JCL_ThrowException(env, IO_EXCEPTION,
-                         "Cannot represent position correctly on this system");
+      JCL_ThrowException (env, IO_EXCEPTION,
+			  "Cannot represent position correctly on this system");
     }
 #endif /* 0 */
 
   result = TARGET_NATIVE_ERROR;
   new_offset = TARGET_NATIVE_MATH_INT_INT64_CONST_MINUS_1;
-  TARGET_NATIVE_FILE_SEEK_BEGIN(native_fd, offset, new_offset, result);
+  TARGET_NATIVE_FILE_SEEK_BEGIN (native_fd, offset, new_offset, result);
 
   if (result != TARGET_NATIVE_OK)
     {
-      JCL_ThrowException(env, IO_EXCEPTION,
-                         TARGET_NATIVE_LAST_ERROR_STRING());
+      JCL_ThrowException (env, IO_EXCEPTION,
+			  TARGET_NATIVE_LAST_ERROR_STRING ());
     }
 }
 
@@ -361,16 +370,18 @@ Java_gnu_java_nio_channels_FileChannelImpl_seek (JNIEnv *env, jobject obj, jlong
  * Exception on error
  */
 JNIEXPORT void JNICALL
-Java_gnu_java_nio_channels_FileChannelImpl_implTruncate (JNIEnv *env, jobject obj, jlong len)
+Java_gnu_java_nio_channels_FileChannelImpl_implTruncate (JNIEnv * env,
+							 jobject obj,
+							 jlong len)
 {
-  int   native_fd;
+  int native_fd;
   jlong file_size;
-  int   bytes_written;
-  jlong save_offset,new_offset;
-  char  data;
-  int   result;
+  int bytes_written;
+  jlong save_offset, new_offset;
+  char data;
+  int result;
 
-  native_fd = get_native_fd(env, obj);
+  native_fd = get_native_fd (env, obj);
 
 #if 0
   /* Should there be such an exception? All native layer macros should
@@ -381,104 +392,106 @@ Java_gnu_java_nio_channels_FileChannelImpl_implTruncate (JNIEnv *env, jobject ob
      to handle 64bit-values the system is limited to 32bit at all, thus
      the application can not do a seek() or something else beyond the
      32bit limit. It this true?
-  */
+   */
 
   /* FIXME: What do we do if len > the max value of off_t on this 32bit
    * system?  How do we detect that and what do we do? */
-  if (CONVERT_OFF_T_TO_JLONG(native_len) != len)
+  if (CONVERT_OFF_T_TO_JLONG (native_len) != len)
     {
-      JCL_ThrowException(env, IO_EXCEPTION,
-                         "Cannot represent position correctly on this system");
+      JCL_ThrowException (env, IO_EXCEPTION,
+			  "Cannot represent position correctly on this system");
       return;
     }
 #endif /* 0 */
 
   /* get file size */
-  TARGET_NATIVE_FILE_SIZE(native_fd, file_size, result);
+  TARGET_NATIVE_FILE_SIZE (native_fd, file_size, result);
   if (result != TARGET_NATIVE_OK)
     {
-      JCL_ThrowException(env, IO_EXCEPTION,
-                         TARGET_NATIVE_LAST_ERROR_STRING());
+      JCL_ThrowException (env, IO_EXCEPTION,
+			  TARGET_NATIVE_LAST_ERROR_STRING ());
       return;
     }
 
   /* Save off current position */
-  TARGET_NATIVE_FILE_TELL(native_fd, save_offset, result);
+  TARGET_NATIVE_FILE_TELL (native_fd, save_offset, result);
   if (result != TARGET_NATIVE_OK)
     {
-      JCL_ThrowException(env, IO_EXCEPTION,
-                         TARGET_NATIVE_LAST_ERROR_STRING());
+      JCL_ThrowException (env, IO_EXCEPTION,
+			  TARGET_NATIVE_LAST_ERROR_STRING ());
       return;
     }
 
-  if (TARGET_NATIVE_MATH_INT_INT64_LT(file_size,len))
+  if (TARGET_NATIVE_MATH_INT_INT64_LT (file_size, len))
     {
       /* File is too short -- seek to one byte short of where we want,
        * then write a byte */
 
       /* move to position n-1 */
-      TARGET_NATIVE_FILE_SEEK_BEGIN(native_fd, TARGET_NATIVE_MATH_INT_INT64_SUB(len,1), new_offset, result);
+      TARGET_NATIVE_FILE_SEEK_BEGIN (native_fd,
+				     TARGET_NATIVE_MATH_INT_INT64_SUB (len,
+								       1),
+				     new_offset, result);
       if (result != TARGET_NATIVE_OK)
-        {
-          JCL_ThrowException(env, IO_EXCEPTION,
-                             TARGET_NATIVE_LAST_ERROR_STRING());
-          return;
-        }
+	{
+	  JCL_ThrowException (env, IO_EXCEPTION,
+			      TARGET_NATIVE_LAST_ERROR_STRING ());
+	  return;
+	}
 
       /* write a byte
          Note: This will fail if we somehow get here in read only mode
-       * That shouldn't happen */
-      data='\0';
-      TARGET_NATIVE_FILE_WRITE(native_fd, &data, 1, bytes_written, result);
+         * That shouldn't happen */
+      data = '\0';
+      TARGET_NATIVE_FILE_WRITE (native_fd, &data, 1, bytes_written, result);
       if (result != TARGET_NATIVE_OK)
-        {
-          JCL_ThrowException(env, IO_EXCEPTION,
-                             TARGET_NATIVE_LAST_ERROR_STRING());
-          return;
-        }
+	{
+	  JCL_ThrowException (env, IO_EXCEPTION,
+			      TARGET_NATIVE_LAST_ERROR_STRING ());
+	  return;
+	}
 
       /* Reposition file pointer to where we started if not beyond new len. */
-      if (TARGET_NATIVE_MATH_INT_INT64_LT(save_offset, len))
+      if (TARGET_NATIVE_MATH_INT_INT64_LT (save_offset, len))
 	{
-	  TARGET_NATIVE_FILE_SEEK_BEGIN(native_fd, save_offset,
-					new_offset, result);
+	  TARGET_NATIVE_FILE_SEEK_BEGIN (native_fd, save_offset,
+					 new_offset, result);
 	  if (result != TARGET_NATIVE_OK)
 	    {
-	      JCL_ThrowException(env, IO_EXCEPTION,
-				 TARGET_NATIVE_LAST_ERROR_STRING());
+	      JCL_ThrowException (env, IO_EXCEPTION,
+				  TARGET_NATIVE_LAST_ERROR_STRING ());
 	      return;
 	    }
 	}
     }
-    else if (TARGET_NATIVE_MATH_INT_INT64_GT(file_size,len))
+  else if (TARGET_NATIVE_MATH_INT_INT64_GT (file_size, len))
     {
       /* File is too long - use ftruncate if available */
 #ifdef HAVE_FTRUNCATE
-      TARGET_NATIVE_FILE_TRUNCATE(native_fd, len, result);
+      TARGET_NATIVE_FILE_TRUNCATE (native_fd, len, result);
       if (result != TARGET_NATIVE_OK)
-      {
-        JCL_ThrowException(env, IO_EXCEPTION,
-                           TARGET_NATIVE_LAST_ERROR_STRING());
-        return;
-      }
+	{
+	  JCL_ThrowException (env, IO_EXCEPTION,
+			      TARGET_NATIVE_LAST_ERROR_STRING ());
+	  return;
+	}
 #else /* HAVE_FTRUNCATE */
       /* FIXME: Probably operation isn't supported, but this exception
        * is too harsh as it will probably crash the program without need
-      JCL_ThrowException(env, "java/lang/UnsupportedOperationException",
-        "not implemented - can't shorten files on this platform");
-      */
-      JCL_ThrowException(env, IO_EXCEPTION,
-                         "Unable to shorten file length");
+       JCL_ThrowException(env, "java/lang/UnsupportedOperationException",
+       "not implemented - can't shorten files on this platform");
+       */
+      JCL_ThrowException (env, IO_EXCEPTION, "Unable to shorten file length");
 #endif /* HAVE_FTRUNCATE */
 
       /* Reposition file pointer when it now is beyond the end of file. */
-      if (TARGET_NATIVE_MATH_INT_INT64_GT(save_offset, len))
+      if (TARGET_NATIVE_MATH_INT_INT64_GT (save_offset, len))
 	{
-	  TARGET_NATIVE_FILE_SEEK_BEGIN(native_fd, len, new_offset, result);
+	  TARGET_NATIVE_FILE_SEEK_BEGIN (native_fd, len, new_offset, result);
 	  if (result != TARGET_NATIVE_OK)
 	    {
-	      JCL_ThrowException(env, IO_EXCEPTION,
-				 TARGET_NATIVE_LAST_ERROR_STRING());
+	      JCL_ThrowException (env, IO_EXCEPTION,
+				  TARGET_NATIVE_LAST_ERROR_STRING ());
 	      return;
 	    }
 	}
@@ -486,17 +499,12 @@ Java_gnu_java_nio_channels_FileChannelImpl_implTruncate (JNIEnv *env, jobject ob
 }
 
 JNIEXPORT jobject JNICALL
-Java_gnu_java_nio_channels_FileChannelImpl_mapImpl(JNIEnv *env,
-						 jobject obj
-						 __attribute__ ((__unused__)),
-						 jchar mode
-						 __attribute__ ((__unused__)),
-						 jlong position
-						 __attribute__ ((__unused__)),
-						 jint size
-						 __attribute__ ((__unused__)))
+Java_gnu_java_nio_channels_FileChannelImpl_mapImpl (JNIEnv * env,
+						    jobject obj
+						    __attribute__ ((__unused__)), jchar mode __attribute__ ((__unused__)), jlong position __attribute__ ((__unused__)), jint size __attribute__ ((__unused__)))
 {
-  JCL_ThrowException (env, IO_EXCEPTION, "java.nio.FileChannelImpl.nio_mmap_file(): not implemented");
+  JCL_ThrowException (env, IO_EXCEPTION,
+		      "java.nio.FileChannelImpl.nio_mmap_file(): not implemented");
   return 0;
 }
 
@@ -505,34 +513,35 @@ Java_gnu_java_nio_channels_FileChannelImpl_mapImpl(JNIEnv *env,
  * Return byte read or -1 on eof, exception on error
  */
 JNIEXPORT jint JNICALL
-Java_gnu_java_nio_channels_FileChannelImpl_read__ (JNIEnv *env, jobject obj)
+Java_gnu_java_nio_channels_FileChannelImpl_read__ (JNIEnv * env, jobject obj)
 {
-  int     native_fd;
-  char    data;
+  int native_fd;
+  char data;
   ssize_t bytes_read;
-  int     result;
+  int result;
 
-  native_fd = get_native_fd(env, obj);
+  native_fd = get_native_fd (env, obj);
 
   bytes_read = 0;
   do
     {
-      TARGET_NATIVE_FILE_READ(native_fd, &data, 1, bytes_read, result);
+      TARGET_NATIVE_FILE_READ (native_fd, &data, 1, bytes_read, result);
       if ((result == TARGET_NATIVE_OK) && (bytes_read == 0))
-        {
-          return(-1);
-        }
+	{
+	  return (-1);
+	}
       if ((result != TARGET_NATIVE_OK)
-          && (TARGET_NATIVE_LAST_ERROR() != TARGET_NATIVE_ERROR_INTERRUPT_FUNCTION_CALL))
-        {
-          JCL_ThrowException(env,IO_EXCEPTION,
-                             TARGET_NATIVE_LAST_ERROR_STRING());
-          return(-1);
+	  && (TARGET_NATIVE_LAST_ERROR () !=
+	      TARGET_NATIVE_ERROR_INTERRUPT_FUNCTION_CALL))
+	{
+	  JCL_ThrowException (env, IO_EXCEPTION,
+			      TARGET_NATIVE_LAST_ERROR_STRING ());
+	  return (-1);
 	}
     }
   while (bytes_read != 1);
 
-  return((jint)(data & 0xFF));
+  return ((jint) (data & 0xFF));
 }
 
 /*
@@ -540,53 +549,59 @@ Java_gnu_java_nio_channels_FileChannelImpl_read__ (JNIEnv *env, jobject obj)
  * Return number of bytes read or -1 on eof, exception on error
  */
 JNIEXPORT jint JNICALL
-Java_gnu_java_nio_channels_FileChannelImpl_read___3BII (JNIEnv *env, jobject obj, jbyteArray buffer, jint offset, jint length)
+Java_gnu_java_nio_channels_FileChannelImpl_read___3BII (JNIEnv * env,
+							jobject obj,
+							jbyteArray buffer,
+							jint offset,
+							jint length)
 {
-  int     native_fd;
-  jbyte   *bufptr;
+  int native_fd;
+  jbyte *bufptr;
   ssize_t bytes_read;
   ssize_t n;
-  int     result;
+  int result;
 
-  native_fd = get_native_fd(env, obj);
+  native_fd = get_native_fd (env, obj);
 
   /* Must return 0 if an attempt is made to read 0 bytes. */
   if (length == 0)
     return 0;
 
-  bufptr = (*env)->GetByteArrayElements(env, buffer, 0);
+  bufptr = (*env)->GetByteArrayElements (env, buffer, 0);
   if (!bufptr)
     {
-      JCL_ThrowException(env, IO_EXCEPTION, "Unexpected JNI error");
-      return(-1);
+      JCL_ThrowException (env, IO_EXCEPTION, "Unexpected JNI error");
+      return (-1);
     }
 
   bytes_read = 0;
   do
     {
-      TARGET_NATIVE_FILE_READ(native_fd, (bufptr + offset + bytes_read), (length - bytes_read), n, result);
+      TARGET_NATIVE_FILE_READ (native_fd, (bufptr + offset + bytes_read),
+			       (length - bytes_read), n, result);
       if ((result == TARGET_NATIVE_OK) && (n == 0))
-        {
-          (*env)->ReleaseByteArrayElements(env, buffer, bufptr, 0);
-          if (bytes_read == 0)
-            return -1; /* Signal end of file to Java */
-          else
-            return CONVERT_SSIZE_T_TO_JINT(bytes_read);
-        }
+	{
+	  (*env)->ReleaseByteArrayElements (env, buffer, bufptr, 0);
+	  if (bytes_read == 0)
+	    return -1;		/* Signal end of file to Java */
+	  else
+	    return CONVERT_SSIZE_T_TO_JINT (bytes_read);
+	}
       if ((result != TARGET_NATIVE_OK)
-          && (TARGET_NATIVE_LAST_ERROR() != TARGET_NATIVE_ERROR_INTERRUPT_FUNCTION_CALL))
-        {
-          JCL_ThrowException(env, IO_EXCEPTION,
-                             TARGET_NATIVE_LAST_ERROR_STRING());
-          (*env)->ReleaseByteArrayElements(env, buffer, bufptr, 0);
-          return -1;
-        }
+	  && (TARGET_NATIVE_LAST_ERROR () !=
+	      TARGET_NATIVE_ERROR_INTERRUPT_FUNCTION_CALL))
+	{
+	  JCL_ThrowException (env, IO_EXCEPTION,
+			      TARGET_NATIVE_LAST_ERROR_STRING ());
+	  (*env)->ReleaseByteArrayElements (env, buffer, bufptr, 0);
+	  return -1;
+	}
       bytes_read += n;
     }
   while (bytes_read < 1);
 
-  (*env)->ReleaseByteArrayElements(env, buffer, bufptr, 0);
-  return CONVERT_SSIZE_T_TO_JINT(bytes_read);
+  (*env)->ReleaseByteArrayElements (env, buffer, bufptr, 0);
+  return CONVERT_SSIZE_T_TO_JINT (bytes_read);
 }
 
 /*
@@ -594,24 +609,27 @@ Java_gnu_java_nio_channels_FileChannelImpl_read___3BII (JNIEnv *env, jobject obj
  * Return status code, exception on error
  */
 JNIEXPORT void JNICALL
-Java_gnu_java_nio_channels_FileChannelImpl_write__I (JNIEnv *env, jobject obj, jint b)
+Java_gnu_java_nio_channels_FileChannelImpl_write__I (JNIEnv * env,
+						     jobject obj, jint b)
 {
-  int     native_fd;
-  char    native_data;
+  int native_fd;
+  char native_data;
   ssize_t bytes_written;
-  int     result;
+  int result;
 
-  native_fd = get_native_fd(env, obj);
-  native_data = (char)(CONVERT_JINT_TO_INT(b) & 0xFF);
+  native_fd = get_native_fd (env, obj);
+  native_data = (char) (CONVERT_JINT_TO_INT (b) & 0xFF);
 
   do
     {
-      TARGET_NATIVE_FILE_WRITE(native_fd, &native_data, 1, bytes_written, result);
+      TARGET_NATIVE_FILE_WRITE (native_fd, &native_data, 1, bytes_written,
+				result);
       if ((result != TARGET_NATIVE_OK)
-          && (TARGET_NATIVE_LAST_ERROR() != TARGET_NATIVE_ERROR_INTERRUPT_FUNCTION_CALL))
-        {
-          JCL_ThrowException(env, IO_EXCEPTION,
-                             TARGET_NATIVE_LAST_ERROR_STRING());
+	  && (TARGET_NATIVE_LAST_ERROR () !=
+	      TARGET_NATIVE_ERROR_INTERRUPT_FUNCTION_CALL))
+	{
+	  JCL_ThrowException (env, IO_EXCEPTION,
+			      TARGET_NATIVE_LAST_ERROR_STRING ());
 	}
     }
   while (result != TARGET_NATIVE_OK);
@@ -622,70 +640,74 @@ Java_gnu_java_nio_channels_FileChannelImpl_write__I (JNIEnv *env, jobject obj, j
  * Return status code, exception on error
  */
 JNIEXPORT void JNICALL
-Java_gnu_java_nio_channels_FileChannelImpl_write___3BII (JNIEnv *env, jobject obj, jbyteArray buffer, jint offset, jint length)
+Java_gnu_java_nio_channels_FileChannelImpl_write___3BII (JNIEnv * env,
+							 jobject obj,
+							 jbyteArray buffer,
+							 jint offset,
+							 jint length)
 {
-  int     native_fd;
-  jbyte   *bufptr;
+  int native_fd;
+  jbyte *bufptr;
   ssize_t bytes_written;
   ssize_t n;
-  int     result;
+  int result;
 
-  native_fd = get_native_fd(env, obj);
+  native_fd = get_native_fd (env, obj);
 
   /* Just return if an attempt is made to write 0 bytes. */
   if (length == 0)
     return;
 
-  bufptr = (*env)->GetByteArrayElements(env, buffer, 0);
+  bufptr = (*env)->GetByteArrayElements (env, buffer, 0);
   if (!bufptr)
     {
-      JCL_ThrowException(env, IO_EXCEPTION, "Unexpected JNI error");
+      JCL_ThrowException (env, IO_EXCEPTION, "Unexpected JNI error");
       return;
     }
 
   bytes_written = 0;
-  while (bytes_written < CONVERT_JINT_TO_SSIZE_T(length))
+  while (bytes_written < CONVERT_JINT_TO_SSIZE_T (length))
     {
-      TARGET_NATIVE_FILE_WRITE(native_fd, (bufptr + offset + bytes_written), (length - bytes_written), n, result);
+      TARGET_NATIVE_FILE_WRITE (native_fd, (bufptr + offset + bytes_written),
+				(length - bytes_written), n, result);
       if ((result != TARGET_NATIVE_OK)
-          && (TARGET_NATIVE_LAST_ERROR() != TARGET_NATIVE_ERROR_INTERRUPT_FUNCTION_CALL))
-        {
-          JCL_ThrowException(env, IO_EXCEPTION,
-                             TARGET_NATIVE_LAST_ERROR_STRING());
-          (*env)->ReleaseByteArrayElements(env, buffer, bufptr, 0);
-          return;
+	  && (TARGET_NATIVE_LAST_ERROR () !=
+	      TARGET_NATIVE_ERROR_INTERRUPT_FUNCTION_CALL))
+	{
+	  JCL_ThrowException (env, IO_EXCEPTION,
+			      TARGET_NATIVE_LAST_ERROR_STRING ());
+	  (*env)->ReleaseByteArrayElements (env, buffer, bufptr, 0);
+	  return;
 	}
       bytes_written += n;
     }
 
-  (*env)->ReleaseByteArrayElements(env, buffer, bufptr, 0);
+  (*env)->ReleaseByteArrayElements (env, buffer, bufptr, 0);
 }
 
 JNIEXPORT jboolean JNICALL
-Java_gnu_java_nio_channels_FileChannelImpl_lock(JNIEnv *env,
-						jobject obj
-						__attribute__ ((__unused__)),
-						jlong position
-						__attribute__ ((__unused__)),
-						jlong size
-						__attribute__ ((__unused__)),
-						jboolean shared
-						__attribute__ ((__unused__)),
-						jboolean wait
-						__attribute__ ((__unused__)))
+Java_gnu_java_nio_channels_FileChannelImpl_lock (JNIEnv * env,
+						 jobject obj
+						 __attribute__ ((__unused__)),
+						 jlong position
+						 __attribute__ ((__unused__)),
+						 jlong size
+						 __attribute__ ((__unused__)),
+						 jboolean shared
+						 __attribute__ ((__unused__)),
+						 jboolean wait
+						 __attribute__ ((__unused__)))
 {
-  JCL_ThrowException (env, IO_EXCEPTION, "java.nio.FileChannelImpl.lock(): not implemented");
+  JCL_ThrowException (env, IO_EXCEPTION,
+		      "java.nio.FileChannelImpl.lock(): not implemented");
   return 0;
 }
 
 JNIEXPORT void JNICALL
-Java_gnu_java_nio_channels_FileChannelImpl_unlock(JNIEnv *env,
-						  jobject obj
-						  __attribute__ ((__unused__)),
-						  jlong position
-						  __attribute__ ((__unused__)),
-						  jlong length
-						  __attribute__ ((__unused__)))
+Java_gnu_java_nio_channels_FileChannelImpl_unlock (JNIEnv * env,
+						   jobject obj
+						   __attribute__ ((__unused__)), jlong position __attribute__ ((__unused__)), jlong length __attribute__ ((__unused__)))
 {
-  JCL_ThrowException (env, IO_EXCEPTION, "java.nio.FileChannelImpl.unlock(): not implemented");
+  JCL_ThrowException (env, IO_EXCEPTION,
+		      "java.nio.FileChannelImpl.unlock(): not implemented");
 }
